/***********************************************************************************************************************
* Copyright (C) All rights reserved.
***********************************************************************************************************************/

/***********************************************************************************************************************
* @file    lcd.h
* @brief   This file implements device driver for LCD module.
* @version 1.0.0
* @date    2022/8/24
***********************************************************************************************************************/
#ifndef LCD_H
#define LCD_H
#include <stdint.h>

/***********************************************************************************************************************
Macro definitions (Register bit)
***********************************************************************************************************************/
#define LCD_VOLTAGE_WAITTIME              (0x8000U)

/** @defgroup LCD_voltage generate mode 
  * @{
  */
#define LCD_Voltage_InterRES							(0x00)
#define LCD_Voltage_InterRise							(0x01)
#define LCD_Voltage_CapDiv					 		  (0x02)
#define LCD_Voltage_ExterRES							(0x03)
#define IS_LCD_Voltage_Mode(Mode)	(((Mode) == LCD_Voltage_InterRES) || \
									((Mode) == LCD_Voltage_InterRise) || \
									((Mode) == LCD_Voltage_CapDiv) || \
									((Mode) == LCD_Voltage_ExterRES))
									
/** @defgroup LCD_Wave Select 
  * @{
  */
#define LCD_Wave_A  											(0x00)
#define LCD_Wave_B  											(0x01)
#define IS_LCD_Wave_Select(wave)	(((wave) == LCD_Wave_A) || ((wave) == LCD_Wave_B))
									
/** @defgroup LCD_time slice Select 
  * @{
  */
#define LCD_TimeSlice_none								(0x00)
#define LCD_TimeSlice2										(0x01)
#define LCD_TimeSlice3										(0x02)
#define LCD_TimeSlice4										(0x03)
#define LCD_TimeSlice6										(0x04)
#define LCD_TimeSlice8										(0x05)
#define IS_LCD_TimeSlice_Select(TimeS)	(((TimeS) == LCD_TimeSlice_none) || \
									((TimeS) == LCD_TimeSlice2) || \
									((TimeS) == LCD_TimeSlice3) || \
									((TimeS) == LCD_TimeSlice4) || \
									((TimeS) == LCD_TimeSlice6) || \
									((TimeS) == LCD_TimeSlice8))
									
/** @defgroup LCD_bias Select 
  * @{
  */
#define LCD_Bias_Half											(0x00)		//1/2 bias
#define LCD_Bias_Third										(0x01)		//1/3 bias
#define LCD_Bias_Quarter									(0x02)		//1/4 bias
#define IS_LCD_Bias_Select(BiasS)	(((BiasS) == LCD_Bias_Half) || \
									((BiasS) == LCD_Bias_Third) || \
									((BiasS) == LCD_Bias_Quarter))
									
/** @defgroup LCD_Graphic Area Select 
  * @{
  */
#define LCD_AreaA_Select									(0x00)
#define LCD_AreaB_Select									(0x01)
#define IS_LCD_Area_Select(AreaS)	(((AreaS) == LCD_AreaA_Select) || \
									((AreaS) == LCD_AreaB_Select))
									
/** @defgroup LCD_Initial Voltage Select 
  * @{
  */
#define LCD_Init_Voltage2700MV						(0x00)
#define LCD_Init_Voltage4200MV						(0x01)
#define IS_LCD_BaseVoltage_Select(BaseVltS)	(((BaseVltS) == LCD_Init_Voltage2700MV) || \
									((BaseVltS) == LCD_Init_Voltage4200MV))
									
/** @defgroup LCD_clcok Select 
  * @{
  */
#define LCD_DIV_fSUBfIL5									(0x04)		// fSUB2^5 or fIL2^5
#define LCD_DIV_fSUBfIL6									(0x05)		//fSUB2^6 or fIL2^6
#define LCD_DIV_fSUBfIL7									(0x06)		//fSUB2^7 or fIL2^7
#define LCD_DIV_fSUBfIL8									(0x07)		//fSUB2^8 or fIL2^8
#define LCD_DIV_fSUBfIL9									(0x08)		//fSUB2^9 or fIL2^9
#define LCD_DIV_fSUB10  									(0x09)		//fSUB2^10
#define LCD_DIV_fMAIN10  									(0x13)		//fMAIN2^10
#define LCD_DIV_fMAIN11  									(0x14)		//fMAIN2^11
#define LCD_DIV_fMAIN12  									(0x15)		//fMAIN2^12
#define LCD_DIV_fMAIN13  									(0x16)		//fMAIN2^13
#define LCD_DIV_fMAIN14  									(0x17)		//fMAIN2^14
#define LCD_DIV_fMAIN15  									(0x18)		//fMAIN2^15
#define LCD_DIV_fMAIN16  									(0x19)		//fMAIN2^16
#define LCD_DIV_fMAIN17  									(0x1a)		//fMAIN2^17
#define LCD_DIV_fMAIN18  									(0x1b)		//fMAIN2^18
#define LCD_DIV_fMAIN19  									(0x2b)		//fMAIN2^19
#define IS_LCD_CLK_Select(CLKS)	(((CLKS) == LCD_DIV_fSUBfIL5) || \
									((CLKS) == LCD_DIV_fSUBfIL6) || ((CLKS) == LCD_DIV_fSUBfIL7) ||\
									((CLKS) == LCD_DIV_fSUBfIL8) || ((CLKS) == LCD_DIV_fSUBfIL9) ||\
									((CLKS) == LCD_DIV_fSUB10)  || ((CLKS) == LCD_DIV_fMAIN10) ||\
									((CLKS) == LCD_DIV_fMAIN11) || ((CLKS) == LCD_DIV_fMAIN12) ||\
									((CLKS) == LCD_DIV_fMAIN13) || ((CLKS) == LCD_DIV_fMAIN14) ||\
									((CLKS) == LCD_DIV_fMAIN15) || ((CLKS) == LCD_DIV_fMAIN16) ||\
									((CLKS) == LCD_DIV_fMAIN17) || ((CLKS) == LCD_DIV_fMAIN18) ||\
									((CLKS) == LCD_DIV_fMAIN19))
									
/** @defgroup LCD_voltage level Select 
  * @{
  */
#define LCD_Voltage_1V										(0x04)		// base voltage is 1.00V
#define LCD_Voltage_1050MV								(0x05)		//base voltage is 1.05V
#define LCD_Voltage_1100V									(0x06)		//base voltage is 1.10V
#define LCD_Voltage_1150V									(0x07)		//base voltage is 1.15V
#define LCD_Voltage_1200V									(0x08)		//base voltage is 1.20V
#define LCD_Voltage_1250V  								(0x09)		//base voltage is 1.25V
#define LCD_Voltage_1300V  								(0x0a)		//base voltage is 1.30V
#define LCD_Voltage_1350V  								(0x0b)		//base voltage is 1.35V
#define LCD_Voltage_1400V  								(0x0c)		//base voltage is 1.40V
#define LCD_Voltage_1450V  								(0x0d)		//base voltage is 1.45V
#define LCD_Voltage_1500V  								(0x0e)		//base voltage is 1.50V
#define LCD_Voltage_1550V  								(0x0f)		//base voltage is 1.55V
#define LCD_Voltage_1600V  								(0x10)		//base voltage is 1.60V
#define LCD_Voltage_1650V  								(0x11)		//base voltage is 1.65V
#define LCD_Voltage_1700V  								(0x12)		//base voltage is 1.70V
#define LCD_Voltage_1750V  								(0x13)		//base voltage is 1.75V
#define IS_LCD_Voltage_Select(VLTAS)	(((VLTAS) == LCD_Voltage_1V) || \
									((VLTAS) == LCD_Voltage_1050MV) || ((VLTAS) == LCD_Voltage_1100V) ||\
									((VLTAS) == LCD_Voltage_1150V) || ((VLTAS) == LCD_Voltage_1200V) ||\
									((VLTAS) == LCD_Voltage_1250V)  || ((VLTAS) == LCD_Voltage_1300V) ||\
									((VLTAS) == LCD_Voltage_1350V) || ((VLTAS) == LCD_Voltage_1400V) ||\
									((VLTAS) == LCD_Voltage_1450V) || ((VLTAS) == LCD_Voltage_1500V) ||\
									((VLTAS) == LCD_Voltage_1550V) || ((VLTAS) == LCD_Voltage_1600V) ||\
									((VLTAS) == LCD_Voltage_1650V) || ((VLTAS) == LCD_Voltage_1700V) ||\
									((VLTAS) == LCD_Voltage_1750V))
									
/** @defgroup LCD_SMIT control 
  * @{
  */
#define LCD_SMIT_VLxOFF										(0x00)		// VLx SMIT OFF
#define LCD_SMIT_VLxON										(0x02)		// VLx SMIT ON
#define IS_LCD_SMITVL_Select(SMITSV)	(((SMITSV) == LCD_SMIT_VLxOFF) || \
									((SMITSV) == LCD_SMIT_VLxON))
									
#define LCD_SMIT_CAPLHOFF									(0x00)		// CAPL CAPH SMIT OFF
#define LCD_SMIT_CAPLHON									(0x01)		// CAPL CAPH SMIT ON
#define IS_LCD_SMITCAP_Select(SMITSCap)	(((SMITSCap) == LCD_SMIT_CAPLHOFF) || \
									((SMITSCap) == LCD_SMIT_CAPLHON))
									
typedef struct
{
	uint8_t VoltageMode;				/*!< This member configures the LCD voltage generate mode. */

	uint8_t LCDWave;			/*!< Specifies the wave of LCD display.
											This parameter can be a value of @ref LCD_Wave_A */

	uint8_t TimeSlice;				/*!< Specifies the time slice of LCD.
											This parameter can be a value of @ref LCD_TimeSlice2 */

	uint8_t Bias;			  	/*!< Specifies the bias. This parameter can be a value of @ref LCD_Bias_Half */

	uint8_t VoltageVM;				  	/*!< Specifies IO the base voltage.
												This parameter can be a value of @ref LCD_Init_Voltage2700MV */

	uint8_t CLKSel; 				    /*!< Specifies the LCD clock */

	uint8_t VContrast; 				    /*!< Specifies the LCD rising voltage control for Contrast */
} LCD_InitTypeDef;
/*
    LCD mode register 0 (LCDM0)
*/
/* LCD drive voltage generator selection (MDSET1, MDSET0) */
#define _00_LCD_VOLTAGE_MODE_INITIALVALUE (0x00U) /* Internal resistance division method */
#define _40_LCD_VOLTAGE_MODE_INTERNAL     (0x40U) /* internal voltage boosting method */
#define _80_LCD_VOLTAGE_MODE_CAPACITOR    (0x80U) /* capacitor split method */
#define _C0_LCD_VOLTAGE_MODE_EXTERNAL     (0xC0U) /* external resistance division method */
/* LCD display waveform selection (LWAVE) */
#define _00_LCD_DISPLAY_WAVEFORM_A        (0x00U) /* A waveform */
#define _20_LCD_DISPLAY_WAVEFORM_B        (0x20U) /* B waveform */
/* LCD time slices and bias mode (LDTY2 - LDTY0, LBAS1, LBAS0) */
#define _16_LCD_DISPLAY_MODE0             (0x16U) /* 8 time slices, 1/4 bias mode */
#define _0D_LCD_DISPLAY_MODE1             (0x0DU) /* 4 time slices, 1/3 bias mode */
#define _09_LCD_DISPLAY_MODE2             (0x09U) /* 3 time slices, 1/3 bias mode */
#define _08_LCD_DISPLAY_MODE3             (0x08U) /* 3 time slices, 1/2 bias mode */
#define _04_LCD_DISPLAY_MODE4             (0x04U) /* 2 time slices, 1/2 bias mode */
#define _00_LCD_DISPLAY_STATIC            (0x00U) /* A waveform external resistance division method: static */

/*
    LCD mode register 1 (LCDM1)
*/
/* LCD display enable/disable (LCDON, SCOC) */
#define _00_LCD_DISPLAY_GROUNG            (0x00U) /* output ground level to segment/common pin */
#define _40_LCD_DISPLAY_OFF               (0x40U) /* display off (all segment outputs are deselected) */
#define _C0_LCD_DISPLAY_ON                (0xC0U) /* display on */
/* Voltage boost circuit and capacitor split circuit operation enable/disable (VLCON) */
#define _00_LCD_BOOST_CAPACITOR_DISABLE   (0x00U) /* stops voltage boost and capacitor split operation */
#define _20_LCD_BOOST_CAPACITOR_ENABLE    (0x20U) /* enables voltage boost and capacitor split operation */
/* Display data area control (BLON, LCDSEL) */
#define _00_LCD_DISPLAY_PATTERN_A         (0x00U) /* displaying an A-pattern area data */
#define _08_LCD_DISPLAY_PATTERN_B         (0x08U) /* displaying a B-pattern area data */
#define _10_LCD_DISPLAY_PATTERN_AB        (0x10U) /* blinking display alternately A-pattern and B-pattern area data */
/* Control of default value of voltage boosting pin (LCDVLM) */
#define _00_LCD_VOLTAGE_STOP              (0x00U) /* stops initialization control of voltage boosting pin operation */
#define _01_LCD_VOLTAGE_ENABLE            (0x01U) /* enables initialization control of voltage boosting pin operation */

/*
    LCD clock control register (LCDC0)
*/
/* LCD clock (LCDCL) selection (LCDC05 - LCDC00) */
#define _04_LCD_CLOCK_FSUB_FIL_5           (0x04U) /* fSUB/2^5 or fIL/2^5 */
#define _05_LCD_CLOCK_FSUB_FIL_6           (0x05U) /* fSUB/2^6 or fIL/2^6 */
#define _06_LCD_CLOCK_FSUB_FIL_7           (0x06U) /* fSUB/2^7 or fIL/2^7 */
#define _07_LCD_CLOCK_FSUB_FIL_8           (0x07U) /* fSUB/2^8 or fIL/2^8 */
#define _08_LCD_CLOCK_FSUB_FIL_9           (0x08U) /* fSUB/2^9 or fIL/2^9 */
#define _09_LCD_CLOCK_FSUB_10              (0x09U) /* fSUB/2^10 */
/* LCD clock (LCDCL) selection (LCDC05 - LCDC00) */
#define _13_LCD_CLOCK_FMAIN_10             (0x13U) /* fMAIN/2^10 */
#define _14_LCD_CLOCK_FMAIN_11             (0x14U) /* fMAIN/2^11 */
#define _15_LCD_CLOCK_FMAIN_12             (0x15U) /* fMAIN/2^12 */
#define _16_LCD_CLOCK_FMAIN_13             (0x16U) /* fMAIN/2^13 */
#define _17_LCD_CLOCK_FMAIN_14             (0x17U) /* fMAIN/2^14 */
#define _18_LCD_CLOCK_FMAIN_15             (0x18U) /* fMAIN/2^15 */
#define _19_LCD_CLOCK_FMAIN_16             (0x19U) /* fMAIN/2^16 */
#define _1A_LCD_CLOCK_FMAIN_17             (0x1AU) /* fMAIN/2^17 */
#define _1B_LCD_CLOCK_FMAIN_18             (0x1BU) /* fMAIN/2^18 */
#define _2B_LCD_CLOCK_FMAIN_19             (0x2BU) /* fMAIN/2^19 */

/*
    LCD boost level control register (VLCD)
*/
/* Reference voltage selection (contrast adjustment) (VLCD4 - VLCD0) */
#define _04_LCD_BOOST_VOLTAGE_100V        (0x04U) /* 1.00 V (1/3 bias: 3.00 V; 1/4 bias: 4.00 V) */
#define _05_LCD_BOOST_VOLTAGE_105V        (0x05U) /* 1.05 V (1/3 bias: 3.15 V; 1/4 bias: 4.20 V) */
#define _06_LCD_BOOST_VOLTAGE_110V        (0x06U) /* 1.10 V (1/3 bias: 3.30 V; 1/4 bias: 4.40 V) */
#define _07_LCD_BOOST_VOLTAGE_115V        (0x07U) /* 1.15 V (1/3 bias: 3.45 V; 1/4 bias: 4.60 V) */
#define _08_LCD_BOOST_VOLTAGE_120V        (0x08U) /* 1.20 V (1/3 bias: 3.60 V; 1/4 bias: 4.80 V) */
#define _09_LCD_BOOST_VOLTAGE_125V        (0x09U) /* 1.25 V (1/3 bias: 3.75 V; 1/4 bias: 5.00 V) */
#define _0A_LCD_BOOST_VOLTAGE_130V        (0x0AU) /* 1.30 V (1/3 bias: 3.90 V; 1/4 bias: 5.20 V) */
#define _0B_LCD_BOOST_VOLTAGE_135V        (0x0BU) /* 1.35 V (1/3 bias: 4.05 V; 1/4 bias: setting prohibited) */
#define _0C_LCD_BOOST_VOLTAGE_140V        (0x0CU) /* 1.40 V (1/3 bias: 4.20 V; 1/4 bias: setting prohibited) */
#define _0D_LCD_BOOST_VOLTAGE_145V        (0x0DU) /* 1.45 V (1/3 bias: 4.35 V; 1/4 bias: setting prohibited) */
#define _0E_LCD_BOOST_VOLTAGE_150V        (0x0EU) /* 1.50 V (1/3 bias: 4.50 V; 1/4 bias: setting prohibited) */
#define _0F_LCD_BOOST_VOLTAGE_155V        (0x0FU) /* 1.55 V (1/3 bias: 4.65 V; 1/4 bias: setting prohibited) */
#define _10_LCD_BOOST_VOLTAGE_160V        (0x10U) /* 1.60 V (1/3 bias: 4.80 V; 1/4 bias: setting prohibited) */
#define _11_LCD_BOOST_VOLTAGE_165V        (0x11U) /* 1.65 V (1/3 bias: 4.95 V; 1/4 bias: setting prohibited) */
#define _12_LCD_BOOST_VOLTAGE_170V        (0x12U) /* 1.70 V (1/3 bias: 5.10 V; 1/4 bias: setting prohibited) */
#define _13_LCD_BOOST_VOLTAGE_175V        (0x13U) /* 1.75 V (1/3 bias: 5.25 V; 1/4 bias: setting prohibited) */

/* 
    LCD input switch control register (ISCLCD)
*/
/* VL3/P125 pin schmitt trigger buffer control (ISCVL3) */
#define _02_LCD_VLx_BUFFER_VALID          (0x02U) /* VLx pin buffer control valid */
#define _00_LCD_VLx_BUFFER_INVALID        (0x00U) /* VLx pin buffer control invalid */
/* CAPL/P126, CAPH/P127 pins schmitt trigger buffer control (ISCCAP) */
#define _01_LCD_CAPLH_BUFFER_VALID        (0x01U) /* CAPL, CAPH pins buffer control valid */
#define _00_LCD_CAPLH_BUFFER_INVALID      (0x00U) /* CAPL, CAPH pins buffer control invalid */

/***********************************************************************************************************************
Macro definitions
***********************************************************************************************************************/

/***********************************************************************************************************************
Typedef definitions
***********************************************************************************************************************/

/***********************************************************************************************************************
Global functions
***********************************************************************************************************************/
void LCDApi_Init(LCD_InitTypeDef* LCD_InitStruct);

/***********************************************************************************************************************
* Function Name: LCD_VoltageMode
* Description  : This function select voltage generate method.
* Arguments    : AreaAB
*                  LCD_Voltage_InterRES: internal ressitance
*									 LCD_Voltage_InterRise: internal rising voltage
*									 LCD_Voltage_CapDiv: capacitance divid
*									 LCD_Voltage_ExterRES: external ressitance
* Return Value : None
***********************************************************************************************************************/
void LCD_VoltageMode(uint8_t VoltMode);

/***********************************************************************************************************************
* Function Name: LCD_WaveSelect
* Description  : This function select wave.
* Arguments    : AreaAB
*                  LCD_Wave_A: A wave
*									 LCD_Wave_B: B wave
* Return Value : None
***********************************************************************************************************************/
void LCD_WaveSelect(uint8_t WaveMode);

/***********************************************************************************************************************
* Function Name: LCD_TimeSliceSelect
* Description  : This function select LCD time slice.
* Arguments    : AreaAB
*                  LCD_TimeSlice_none: stop
*									 LCD_TimeSlice2: 2 time slice
*									 LCD_TimeSlice3: 3 time slice
*									 LCD_TimeSlice4: 4 time slice
*									 LCD_TimeSlice6: 6 time slice
*									 LCD_TimeSlice8: 8 time slice
* Return Value : None
***********************************************************************************************************************/
void LCD_TimeSliceSelect(uint8_t TimeSlice);

/***********************************************************************************************************************
* Function Name: LCD_BiasSelect
* Description  : This function select LCD Bias.
* Arguments    : BiasVal
*                  LCD_Bias_Half: 1/2 bias
*									 LCD_Bias_Third: 1/3 bias
*									 LCD_Bias_Quarter: 1/4 bias
* Return Value : None
***********************************************************************************************************************/
void LCD_BiasSelect(uint8_t BiasVal);

	
/***********************************************************************************************************************
* Function Name: LCD_DispAreaSelect
* Description  : This function select display area A or B.
* Arguments    : AreaAB
*                  LCD_AreaA_Select: Graphic A
*									 LCD_AreaB_Select: Graphic B
* Return Value : None
***********************************************************************************************************************/
void LCD_DispAreaSelect(uint8_t AreaAB);

/***********************************************************************************************************************
* Function Name: LCD_InitVoltageSelect
* Description  : This function select the LCD initial voltage.
* Arguments    : InitV
*                  LCD_Init_Voltage2700MV: 2.7V
*									 LCD_Init_Voltage4200MV: 4.2V
* Return Value : None
***********************************************************************************************************************/
void LCD_InitVoltageSelect(uint8_t InitV);

/***********************************************************************************************************************
* Function Name: LCD_CLK_Select
* Description  : This function select LCD clock.
* Arguments    : LCDCLK
*                  LCD_DIV_fSUBfIL5: fSUB2^5 or fIL2^5
*                  LCD_DIV_fSUBfIL6: fSUB2^6 or fIL2^6
*                  LCD_DIV_fSUBfIL7: fSUB2^7 or fIL2^7
*                  LCD_DIV_fSUBfIL8: fSUB2^8 or fIL2^8
*                  LCD_DIV_fSUBfIL9: fSUB2^9 or fIL2^9
*                  LCD_DIV_fSUB10:   fSUB2^10
*                  LCD_DIV_fMAIN10:  fMAIN2^10
*                  LCD_DIV_fMAIN11:  fMAIN2^11
*                  LCD_DIV_fMAIN12:  fMAIN2^12
*                  LCD_DIV_fMAIN13:  fMAIN2^13
*                  LCD_DIV_fMAIN14:  fMAIN2^14
*                  LCD_DIV_fMAIN15:  fMAIN2^15
*                  LCD_DIV_fMAIN16:  fMAIN2^16
*                  LCD_DIV_fMAIN17:  fMAIN2^17
*                  LCD_DIV_fMAIN18:  fMAIN2^18
*                  LCD_DIV_fMAIN19:  fMAIN2^19
* Return Value : None
***********************************************************************************************************************/
void LCD_CLK_Select(uint8_t LCDCLK);

/***********************************************************************************************************************
* Function Name: LCD_Voltage_RiseLevel
* Description  : This function select LCD base voltage level.
* Arguments    : LCDCLK
* 									LCD_Voltage_1V		  :base voltage is 1.00V
* 									LCD_Voltage_1050MV	:base voltage is 1.05V
* 									LCD_Voltage_1100V		:base voltage is 1.10V
* 									LCD_Voltage_1150V		:base voltage is 1.15V
* 									LCD_Voltage_1200V		:base voltage is 1.20V
* 									LCD_Voltage_1250V  	:base voltage is 1.25V
* 									LCD_Voltage_1300V  	:base voltage is 1.30V
* 									LCD_Voltage_1350V  	:base voltage is 1.35V
* 									LCD_Voltage_1400V  	:base voltage is 1.40V
* 									LCD_Voltage_1450V  	:base voltage is 1.45V
* 									LCD_Voltage_1500V  	:base voltage is 1.50V
* 									LCD_Voltage_1550V  	:base voltage is 1.55V
* 									LCD_Voltage_1600V  	:base voltage is 1.60V
* 									LCD_Voltage_1650V  	:base voltage is 1.65V
* 									LCD_Voltage_1700V  	:base voltage is 1.70V
* 									LCD_Voltage_1750V  	:base voltage is 1.75V
* Return Value : None
***********************************************************************************************************************/
void LCD_Voltage_RiseLevel(uint8_t LCDVLT);

/***********************************************************************************************************************
* Function Name: LCD_SmitContrl
* Description  : This function enables the IO SMIT function.
* Arguments    : SMITVLx
* 									LCD_SMIT_VLxOFF  	:SMIT on VLx no work
* 									LCD_SMIT_VLxON  	:SMIT on VLx Open
* Arguments    : SMITCAP
* 									LCD_SMIT_CAPLHOFF  	:SMIT on CAPL/CAPH no work
* 									LCD_SMIT_CAPLHON  	:SMIT on CAPL/CAPH Open
* Return Value : None
***********************************************************************************************************************/
void LCD_SmitContrl(uint8_t SMITVLx, uint8_t SMITCAP);
void LCD_Start(void);
void LCD_Stop(void);
void LCD_Voltage_On(void);
void LCD_Voltage_Off(void);

/* Start user code for function. Do not edit comment generated here */
/* End user code. Do not edit comment generated here */
#endif
