/*******************************************************************************
* Copyright (C) 2019 China Micro Semiconductor Limited Company. All Rights Reserved.
*
* This software is owned and published by:
* CMS LLC, No 2609-10, Taurus Plaza, TaoyuanRoad, NanshanDistrict, Shenzhen, China.
*
* BY DOWNLOADING, INSTALLING OR USING THIS SOFTWARE, YOU AGREE TO BE BOUND
* BY ALL THE TERMS AND CONDITIONS OF THIS AGREEMENT.
*
* This software contains source code for use with CMS
* components. This software is licensed by CMS to be adapted only
* for use in systems utilizing CMS components. CMS shall not be
* responsible for misuse or illegal use of this software for devices not
* supported herein. CMS is providing this software "AS IS" and will
* not be responsible for issues arising from incorrect user implementation
* of the software.
*
* This software may be replicated in part or whole for the licensed use,
* with the restriction that this Disclaimer and Copyright notice must be
* included with each copy of this software, whether used in part or whole,
* at all times.
*/

/*****************************************************************************/
/** \file opa.h
**
** History:
** 
*****************************************************************************/
#ifndef __OPA_H_
#define __OPA_H_

#ifdef __cplusplus
extern "C"
{
#endif

/*****************************************************************************/
/* Include files */
/*****************************************************************************/
#include "common.h"
#include "cgc.h"
/*****************************************************************************/
/* Global pre-processor symbols/macros ('#define') */
/*****************************************************************************/


/*****************************************************************************/
/* Global type definitions ('typedef') */
/*****************************************************************************/
typedef enum
{
	OPA_Current_none  = 0,
	OPA_Current_on  = 1,
}	OPA_Current_t;

typedef enum
{
	OPA_Mode_StableCurrent  = 0,
	OPA_Mode_Buff  = 1,
}	OPA_Mode_t;

typedef enum
{
	OPA_Input_5bitDAC  = 0,
	OPA_Input_8bitDAC  = 1,
}	OPA_Input_t;

typedef enum
{
	OPA_5bitDacP_OpaP  = 0,
	OPA_5bitDacP_Ext  = 1,   //opa_dac
}	OPA_5bitDacP_t;


typedef struct
{
	OPA_Current_t OPA_Current;				/*!< This member configures the OPA internnal current. */

	OPA_Mode_t OPA_Mode;			/*!< Specifies the mode of OPA
											This parameter can be a value of @ref OPA_Mode_Buff */

	OPA_Input_t OPA_Input;				/*!< Specifies the input of OPA.
											This parameter can be a value of @ref OPA_Input_8bitDAC */

	OPA_5bitDacP_t OPA_5bitDacP;			  	/*!< Specifies the 5-bit DAC power input.
											This parameter can be a value of @ref OPA_5bitDacP_Ext */
	uint8_t Dac_Out;          /*!< Specifies the out of 5 bit DAC.
											This parameter can be a value of 0~31*/
} OPA_InitTypeDef;

/*****************************************************************************/
/* Global variable declarations ('extern', definition in C source) */
/*****************************************************************************/


/*****************************************************************************/
/* Global function prototypes ('extern', definition in C source) */
/*****************************************************************************/
/*****************************************************************************
 ** \brief	 OPA_ConfigRunMode
 **			 ˷ģʽ
 ** \param [in] 
 **				mode: (1)OPA_Mode_StableCurrent
 **					  (2)OPA_Mode_Buff
 ** \return  none
 ** \note   
 *****************************************************************************/
void OPA_ConfigRunMode(uint32_t mode);

/*****************************************************************************
 ** \brief	 OPA_ConfigPositive
 **			 ˷
 ** \param [in] 
 **				PositiveSource:  (1)OPA_Input_5bitDAC
 **								 (2)OPA_Input_8bitDAC
 ** \return  none
 ** \note   
 *****************************************************************************/
void OPA_ConfigPositive( uint32_t PositiveSource);

/*****************************************************************************
 ** \brief	 OPA_ConfigCurrent
 **			 ˷
 ** \param [in] 
 **				CurrentSource:  (1)OPA_Current_none
 **								 (2)OPA_Current_on
 ** \return  none
 ** \note    
 *****************************************************************************/
void OPA_ConfigCurrent(uint32_t CurrentSource);


/*****************************************************************************
 ** \brief	 OPA_ConfigDACPower
 **			 ˷
 ** \param [in] 
 **				DACPower:  (1)OPA_5bitDacP_OpaP
 **								 (2)OPA_5bitDacP_Ext
 ** \return  none
 ** \note    
 *****************************************************************************/
void OPA_ConfigDACPower(uint32_t DACPower);

/*****************************************************************************
 ** \brief	 OPA_SetOut
 **			 5bit DAC
 ** \param [in] 0~31
 ** \return  none
 ** \note    
 *****************************************************************************/
void OPA_SetOut(uint32_t DACOut);

/********************************************************************************
 ** \brief	 OPA_Start
 **			 OP
 ** \param [in] 
 ** \return  none
 ** \note   
 ******************************************************************************/
void OPA_Start(void);

/********************************************************************************
 ** \brief	 OPA_Stop
 **			 رOP
 ** \param [in] 
 ** \return  none
 ** \note   
 ******************************************************************************/
void OPA_Stop(void);
void OPA_Init(OPA_InitTypeDef* OPA_InitStruct);

#ifdef __cplusplus
}
#endif

#endif /* __OPA_H_ */

