#include "cmp.h"
#include "cgc.h"
//#define TESOPT  *((volatile uint8_t *)(0x4004384C))  /*!< (@ 0x4004384C) PGA protect register                          */



/***********************************************************************************************************************
* Function Name: CMP_Input_Select
* @brief  This function sets the positive and negative side input of Comparator.
* @param  ch - specify the comp channel number
* @param  positive_side - specify the positive side input of Comparator
* @param  negative_side - specify the negative side input of Comparator
* @return None
***********************************************************************************************************************/
void CMP_Input_Select(CMP_Channel_t ch, CMP_Side_t positive_side, CMP_Side_t negative_side)
{
    if(ch & 0x01)
    {
        CMP->CMPSEL0 = positive_side;
				CMP->C0REFS = negative_side;
	}
    if(ch & 0x02)
    {
        CMP->CMPSEL1 = positive_side;
				CMP->C1REFS = negative_side;
	}
}

/***********************************************************************************************************************
* Function Name: CMP_Init
* @brief  This function initilize the CMP.
***********************************************************************************************************************/
void CMP_Init(CMP_InitTypeDef* CMP_InitStruct)
{
	uint8_t rtemp=0;
	
	CGC_PER1PeriphClockCmd(CGC_PER1Periph_CMP,ENABLE);

	if(CMP_InitStruct->CMP_Channel & CMP_Channel_0)
	{
		
		CMP->CMPSEL0 = CMP_InitStruct->CMP_PositiveSide;  //set the positive input
		CMP->C0REFS = CMP_InitStruct->CMP_NegativeSide;   //set the negative input
		
		CMP->CMP0HY = CMP_InitStruct->CMP_HyMode + ((CMP_InitStruct->CMP_HyVal) << 4); //set the Hysteresis
		rtemp = CMP->COMPFIR;
		rtemp &= ~(CMP_COMPFIR_C0FCK_Msk | CMP_COMPFIR_C0EPO_Msk | CMP_COMPFIR_C0EDG_Msk);
		rtemp |= CMP_InitStruct->CMP_Filter | ((CMP_InitStruct->CMP_IntReq)<< CMP_COMPFIR_C0EPO_Pos);
		CMP->COMPFIR = rtemp;
		
		rtemp = CMP->COMPOCR;
		rtemp &= ~(CMP_COMPOCR_C0IE_Msk | CMP_COMPOCR_C0OE_Msk | CMP_COMPOCR_C0OP_Msk);
		rtemp |= (CMP_InitStruct->CMP_Int) | (CMP_InitStruct->CMP_Out2port << CMP_COMPOCR_C0OE_Pos) | (CMP_InitStruct->CMP_Polarity << CMP_COMPOCR_C0OP_Pos);
		CMP->COMPOCR = rtemp;
		
		CMP->COMPMDR |= CMP_COMPMDR_C0ENB_Msk;		//start CMP0
	}
	if(CMP_InitStruct->CMP_Channel & CMP_Channel_1)
	{
		CMP->CMPSEL1 = CMP_InitStruct->CMP_PositiveSide;  //set the positive input
		CMP->C1REFS = CMP_InitStruct->CMP_NegativeSide;   //set the negative input
		CMP->CMP1HY = CMP_InitStruct->CMP_HyMode + ((CMP_InitStruct->CMP_HyVal) << 4); //set the Hysteresis
		
		rtemp = CMP->COMPFIR;
		rtemp &= ~(CMP_COMPFIR_C1FCK_Msk | CMP_COMPFIR_C1EPO_Msk | CMP_COMPFIR_C1EDG_Msk);
		rtemp |= (CMP_InitStruct->CMP_Filter  << CMP_COMPFIR_C1FCK_Pos) | ((CMP_InitStruct->CMP_IntReq)<< CMP_COMPFIR_C1EPO_Pos);
		CMP->COMPFIR = rtemp;
		
		rtemp = CMP->COMPOCR;
		rtemp &= ~(CMP_COMPOCR_C1IE_Msk | CMP_COMPOCR_C1OE_Msk | CMP_COMPOCR_C1OP_Msk);
		rtemp |= (CMP_InitStruct->CMP_Int << CMP_COMPOCR_C1IE_Pos) | (CMP_InitStruct->CMP_Out2port << CMP_COMPOCR_C1OE_Pos) 
		         | (CMP_InitStruct->CMP_Polarity << CMP_COMPOCR_C1OP_Pos);
		CMP->COMPOCR = rtemp;
		
		CMP->COMPMDR |= CMP_COMPMDR_C1ENB_Msk;		//start CMP1
	}	
}

/***********************************************************************************************************************
* Function Name: CMP_Start
* @brief  This function starts the Comparator.
* @param  ch - specify the channel
***********************************************************************************************************************/
void CMP_Start(CMP_Channel_t ch)
{
    if(ch & 0x01)
    {
        CMP->COMPMDR |= CMP_COMPMDR_C0ENB_Msk;
	}
    if(ch & 0x02)
    {
        CMP->COMPMDR |= CMP_COMPMDR_C1ENB_Msk;
	}
}
/***********************************************************************************************************************
* Function Name: CMP_Stop
* @brief  This function starts the Comparator.
* @param  ch - specify the channel
***********************************************************************************************************************/
void CMP_Stop(CMP_Channel_t ch)
{
    if(ch & 0x01)
    {
        CMP->COMPMDR &= ~CMP_COMPMDR_C0ENB_Msk;
	}
    if(ch & 0x02)
    {
        CMP->COMPMDR &= ~CMP_COMPMDR_C1ENB_Msk;
	}
}

/***********************************************************************************************************************
* Function Name: CMP_INTConfig
* @brief  This function starts the Comparator interrupt.
* @param  ch - specify the channel
***********************************************************************************************************************/
void CMP_INTConfig(CMP_Channel_t ch)
{
    if(ch & 0x01)
    {
        INTC_ClearPendingIRQ(CMP0_IRQn);    // clear INTCMP0 interrupt flag 
        INTC_EnableIRQ(CMP0_IRQn);          // enable INTCMP0 interrupt 
	}
    if(ch & 0x02)
    {
        INTC_ClearPendingIRQ(CMP1_IRQn);    // clear INTCMP1 interrupt flag 
        INTC_EnableIRQ(CMP1_IRQn);          // enable INTCMP1 interrupt 
	}
}

/***********************************************************************************************************************
* Function Name: CMP_INT_Stop
* @brief  This function stop the Comparator interrupt.
* @param  ch - specify the channel
***********************************************************************************************************************/
void CMP_INT_Stop(CMP_Channel_t ch)
{
    if(ch & 0x01)
    {
        INTC_DisableIRQ(CMP0_IRQn);         // disable INTCMP0 interrupt 
        INTC_ClearPendingIRQ(CMP0_IRQn);    // clear INTCMP0 interrupt flag 
	}
    if(ch & 0x02)
    {
        INTC_DisableIRQ(CMP1_IRQn);         // disable INTCMP1 interrupt
        INTC_ClearPendingIRQ(CMP1_IRQn);    // clear INTCMP1 interrupt flag
	}
}

