#include "dac.h"
#include "cgc.h"


/**
  * @brief  Enable the specified DAC channel .
  * @param  None
  * @retval None
  */
void DAC_Start(void)
{
	DAC->DAM |= DAC_DAM_DACE0_Msk;
}

/**
  * @brief  Disable the specified DAC peripheral.
  * @param  None
  * @retval None
  */
void DAC_Stop(void)
{
	DAC->DAM &= ~DAC_DAM_DACE0_Msk;
}

/**
  * @brief  Config the DAC work mode.
  * @param  DacMod:
  *               DAC_Mode_Normal:通常运行模式
  *               DAC_Mode_RealtimeOut:实时输出模式
  * @retval None
  */
void DAC_Mode(DAC_Mode_t DacMod)
{
	if(DacMod == DAC_Mode_Normal)
		DAC->DAM &= ~DAC_DAM_DAMD0_Msk;
	else
		DAC->DAM |= DAC_DAM_DAMD0_Msk;
}

/**
  * @brief  Set the DAC out.
  * @param  DacMod:
  *               DAC_Mode_Normal:通常运行模式
  *               DAC_Mode_RealtimeOut:实时输出模式
  * @retval None
  */
void DAC_OutSet(uint8_t DacVal)
{
	DAC->DACS0 = DacVal;
}

/**
  * @brief  Initializes the DAC peripheral according to the specified
  *         parameters in the DAC_InitStruct .
  * @param  DAC_InitStruct: pointer to a DAC_InitTypeDef structure that contains
  *         the configuration information for the specified DAC peripheral.
  * @retval None
  */
void DAC_Init(DAC_InitTypeDef* DAC_InitStruct)
{
	assert_param(IS_DAC_MODE(DAC_InitStruct->DAC_Mode));
	
	CGC_PER1PeriphClockCmd(CGC_PER1Periph_DAC,ENABLE);
	
	if(DAC_InitStruct->DAC_Mode == DAC_Mode_Normal)
		DAC->DAM &= ~DAC_DAM_DAMD0_Msk;
	else
		DAC->DAM |= DAC_DAM_DAMD0_Msk;
	
  DAC->DACS0 = DAC_InitStruct->DACValue;
	
	//start DAC
	DAC->DAM |= DAC_DAM_DACE0_Msk; 
	
}






