/***********************************************************************************************************************
* Copyright (C) All rights reserved.
***********************************************************************************************************************/

/***********************************************************************************************************************
* @file    userdefine.h
* @brief   This file includes user definition.
* @version 1.0.0
* @date    2022/8/24
***********************************************************************************************************************/
#ifndef _USER_DEF_H
#define _USER_DEF_H

/***********************************************************************************************************************
User definitions
***********************************************************************************************************************/
#ifndef __TYPEDEF__

typedef unsigned short 	MD_STATUS;
/* Status list definition */
#define MD_STATUSBASE        (0x00U)
#define MD_OK                (MD_STATUSBASE + 0x00U) /* register setting OK */
#define MD_SPT               (MD_STATUSBASE + 0x01U) /* IIC stop */
#define MD_NACK              (MD_STATUSBASE + 0x02U) /* IIC no ACK */
#define MD_BUSY1             (MD_STATUSBASE + 0x03U) /* busy 1 */
#define MD_BUSY2             (MD_STATUSBASE + 0x04U) /* busy 2 */
#define MD_OVERRUN           (MD_STATUSBASE + 0x05U) /* IIC OVERRUN occur */

/* Error list definition */
#define MD_ERRORBASE         (0x80U)
#define MD_ERROR             (MD_ERRORBASE + 0x00U)  /* error */
#define MD_ARGERROR          (MD_ERRORBASE + 0x01U)  /* error agrument input error */
#define MD_ERROR1            (MD_ERRORBASE + 0x02U)  /* error 1 */
#define MD_ERROR2            (MD_ERRORBASE + 0x03U)  /* error 2 */
#define MD_ERROR3            (MD_ERRORBASE + 0x04U)  /* error 3 */
#define MD_ERROR4            (MD_ERRORBASE + 0x05U)  /* error 4 */
#define MD_ERROR5            (MD_ERRORBASE + 0x06U)  /* error 5 */
#endif


//#define RTL_SIMULATION

/***********************************************************************************************************************
Macro definitions of SCI usage:
Each channel of SCI has three functions: UART, SPI, and IIC. You can only choose one function to use.
***********************************************************************************************************************/
/* ToDo: You can only define ONE of the following THREE MACROs according to your application */
#define USE_SCI_UART0_TX      /*! Using CH0 of SCI0 as UART Transmitter */
//#define USE_SCI_SPI00         /*! Using CH0 of SCI0 as SPI Transmitter or Receiver */
//#define USE_SCI_IIC00         /*! Using CH0 of SCI0 as IIC Transmitter or Receiver */
#if ((defined(USE_SCI_UART0_TX) & defined(USE_SCI_SPI00))|\
     (defined(USE_SCI_UART0_TX) & defined(USE_SCI_IIC00))|\
     (defined(USE_SCI_SPI00)    & defined(USE_SCI_IIC00)))
    #error "Multi-functions declared of SCI00."
#endif

/* ToDo: You can only define ONE of the following THREE MACROs according to your application */
#define USE_SCI_UART0_RX      /*! Using CH1 of SCI0 as UART Receiver */
//#define USE_SCI_SPI01         /*! Using CH1 of SCI0 as SPI Transmitter or Receiver */
//#define USE_SCI_IIC01         /*! Using CH1 of SCI0 as IIC Transmitter or Receiver */
#if ((defined(USE_SCI_UART0_RX) & defined(USE_SCI_SPI01))|\
     (defined(USE_SCI_UART0_RX) & defined(USE_SCI_IIC01))|\
     (defined(USE_SCI_SPI01)    & defined(USE_SCI_IIC01)))
    #error "Multi-functions declared of SCI01."
#endif

/* ToDo: You can only define ONE of the following THREE MACROs according to your application */
#define USE_SCI_UART1_TX      /*! Using CH0 of SCI1 as UART Transmitter */
//#define USE_SCI_SPI10         /*! Using CH0 of SCI1 as SPI Transmitter or Receiver */
//#define USE_SCI_IIC10         /*! Using CH0 of SCI1 as IIC Transmitter or Receiver */
#if ((defined(USE_SCI_UART1_TX) & defined(USE_SCI_SPI10))|\
     (defined(USE_SCI_UART1_TX) & defined(USE_SCI_IIC10))|\
     (defined(USE_SCI_SPI10)    & defined(USE_SCI_IIC10)))
    #error "Multi-functions declared of SCI10."
#endif

/* ToDo: You can only define ONE of the following THREE MACROs according to your application */
#define USE_SCI_UART1_RX      /*! Using CH1 of SCI1 as UART Receiver */
//#define USE_SCI_SPI11         /*! Using CH1 of SCI1 as SPI Transmitter or Receiver */
//#define USE_SCI_IIC11         /*! Using CH1 of SCI1 as IIC Transmitter or Receiver */
#if ((defined(USE_SCI_UART1_RX) & defined(USE_SCI_SPI11))|\
     (defined(USE_SCI_UART1_RX) & defined(USE_SCI_IIC11))|\
     (defined(USE_SCI_SPI11)    & defined(USE_SCI_IIC11)))
    #error "Multi-functions declared of SCI11."
#endif

/* ToDo: You can only define ONE of the following THREE MACROs according to your application */
#define USE_SCI_UART2_TX      /*! Using CH0 of SCI2 as UART Transmitter */
//#define USE_SCI_SPI20         /*! Using CH0 of SCI2 as SPI Transmitter or Receiver */
//#define USE_SCI_IIC20         /*! Using CH0 of SCI2 as IIC Transmitter or Receiver */
#if ((defined(USE_SCI_UART2_TX) & defined(USE_SCI_SPI20))|\
     (defined(USE_SCI_UART2_TX) & defined(USE_SCI_IIC20))|\
     (defined(USE_SCI_SPI20)    & defined(USE_SCI_IIC20)))
    #error "Multi-functions declared of SCI20."
#endif

/* ToDo: You can only define ONE of the following THREE MACROs according to your application */
#define USE_SCI_UART2_RX      /*! Using CH1 of SCI2 as UART Receiver */
//#define USE_SCI_SPI21         /*! Using CH1 of SCI2 as SPI Transmitter or Receiver */
//#define USE_SCI_IIC21         /*! Using CH1 of SCI2 as IIC Transmitter or Receiver */
#if ((defined(USE_SCI_UART2_RX) & defined(USE_SCI_SPI21))|\
     (defined(USE_SCI_UART2_RX) & defined(USE_SCI_IIC21))|\
     (defined(USE_SCI_SPI21)    & defined(USE_SCI_IIC21)))
    #error "Multi-functions declared of SCI21."
#endif

/* ToDo: You can define the following MACRO and USE_SCI_UART2_TX or USE_SCI_UART2_RX MACROs to use Infra-Red transmitter or receiver */
//#define USE_IRDA              /*! Enable Infra-Red transmission with UART2 */

/***********************************************************************************************************************
DMA Control Data Set definitions
***********************************************************************************************************************/
#define SPI00_WITH_DMA
#define CTRL_DATA_SPI00 0

//#define SPI01_WITH_DMA
//#define CTRL_DATA_SPI01 2

//#define SPI10_WITH_DMA
//#define CTRL_DATA_SPI10 4

#define SPI11_WITH_DMA
#define CTRL_DATA_SPI11 6

//#define SPI20_WITH_DMA
//#define CTRL_DATA_SPI20 8

//#define SPI21_WITH_DMA
//#define CTRL_DATA_SPI21 10

#define SPIHS0_WITH_DMA
#define CTRL_DATA_SPIHS0 12

#define ADC_WITH_DMA
#define CTRL_DATA_ADC   14

#define DAC_WITH_DMA
#define CTRL_DATA_DAC   16

/***********************************************************************************************************************
Typedef definitions
***********************************************************************************************************************/
typedef enum 
{
    SPI_MODE_0 = 0,  // Mode 0: CPOL = 0, CPHA = 0; i.e. CKP = 1, DAP = 1 
    SPI_MODE_1 = 1,  // Mode 1: CPOL = 0, CPHA = 1; i.e. CKP = 1, DAP = 0 
    SPI_MODE_2 = 2,  // Mode 2: CPOL = 1, CPHA = 0; i.e. CKP = 0, DAP = 1 
    SPI_MODE_3 = 3,  // Mode 3: CPOL = 1, CPHA = 1; i.e. CKP = 0, DAP = 0 
} spi_mode_t;

/** @addtogroup Peripherals_Port_Setting_Definations
  * @{
  */

/* ================================================================================================================== */
/* ================                                       TM8                                        ================ */
/* ================================================================================================================== */

/**
  * @brief TM8 TI00~7 and TO00~7 Port Setting 
  */

/* ToDo: You can allocate the TI00 to PA00,PA08,PB00,PB09,PC00 and PC08 pins */
#define TI00_PORT_SETTING() do{ \
        PORT->PA00CFG = 0x02;	    /* allocate TI00 to PA00 */ \
        PORT->PMA  |=  (1 << 0);    /* PA00 is used as TI00 input */ \
        PORT->PMCA &= ~(1 << 0);    /* PA00 digital function */ \
}while(0)

/* ToDo: You can allocate the TI01 to PA01,PA09,PB01,PC01,PC09,PD03 and PH02 pins */
#define TI01_PORT_SETTING() do{ \
        PORT->PA01CFG = 0x03;	    /* allocate TI01 to PA01 */ \
        PORT->PMA  |=  (1 << 1);    /* PA01 is used as TI01 input */ \
        PORT->PMCA &= ~(1 << 1);    /* PA01 digital function */ \
}while(0)

/* ToDo: You can allocate the TI02 to PA02,PA10,PB02,PB10,PC02,PC10 and PD02 pins */
#define TI02_PORT_SETTING() do{ \
        PORT->PA02CFG = 0x03;	    /* allocate TI02 to PA02 */ \
        PORT->PMA  |=  (1 << 2);    /* PA02 is used as TI02 input */ \
        PORT->PMCA &= ~(1 << 2);    /* PA02 digital function */ \
}while(0)

/* ToDo: You can allocate the TI03 to PA03,PA11,PB03,PB11,PC03 and PC11 pins */
#define TI03_PORT_SETTING() do{ \
        PORT->PA03CFG = 0x03;	    /* allocate TI03 to PA03 */ \
        PORT->PMA  |=  (1 << 3);    /* PA03 is used as TI03 input */ \
        PORT->PMCA &= ~(1 << 3);    /* PA03 digital function */ \
}while(0)

/* ToDo: You can allocate the TI04 to PA04,PA12,PB04,PB12,PC04 and PC12 pins */
#define TI04_PORT_SETTING() do{ \
        PORT->PA04CFG = 0x03;	    /* allocate TI04 to PA04 */ \
        PORT->PMA  |=  (1 << 4);    /* PA04 is used as TI04 input */ \
        PORT->PMCA &= ~(1 << 4);    /* PA04 digital function */ \
}while(0)

/* ToDo: You can allocate the TI05 to PA05,PA13,PB05,PB13,PC05 and PC13 pins */
#define TI05_PORT_SETTING() do{ \
        PORT->PA05CFG = 0x03;	    /* allocate TI05 to PA05 */ \
        PORT->PMA  |=  (1 << 5);    /* PA05 is used as TI05 input */ \
        PORT->PMCA &= ~(1 << 5);    /* PA05 digital function */ \
}while(0)

/* ToDo: You can allocate the TI06 to PA06,PA14,PB06,PB14,PC06 and PC14 pins */
#define TI06_PORT_SETTING() do{ \
        PORT->PA06CFG = 0x03;	    /* allocate TI06 to PA06 */ \
        PORT->PMA  |=  (1 << 6);    /* PA06 is used as TI02 input */ \
        PORT->PMCA &= ~(1 << 6);    /* PA06 digital function */ \
}while(0)

/* ToDo: You can allocate the TI07 to PA07,PA15,PB07,PB15 and PC07 pins */
#define TI07_PORT_SETTING() do{ \
        PORT->PA07CFG = 0x03;	    /* allocate TI07 to PA07 */ \
        PORT->PMA  |=  (1 << 7);    /* PA07 is used as TI03 input */ \
        PORT->PMCA &= ~(1 << 7);    /* PA07 digital function */ \
}while(0)

/* ToDo: You can allocate the TO00 to PA00,PA08,PB00,PB09,PC00 and PC08 pins */
#define TO00_PORT_SETTING() do{ \
        PORT->PA00CFG = 0x03;	    /* allocate TO00 to PA00 */ \
        PORT->PCLRA =  (1 << 0);    /* PA00 output low level */ \
        PORT->PMA  &= ~(1 << 0);    /* PA00 is used as TO00 output */ \
        PORT->POMA &= ~(1 << 0);    /* PA00 is normal output mode */ \
        PORT->PMCA &= ~(1 << 0);    /* PA00 digital function */ \
}while(0)

/* ToDo: You can allocate the TO01 to PA01,PA09,PB01,PC01,PC09,PD03 and PH02 pins */
#define TO01_PORT_SETTING() do{ \
        PORT->PA01CFG = 0x03;	    /* allocate TO01 to PA01 */ \
        PORT->PCLRA =  (1 << 1);    /* PA01 output low level */ \
        PORT->PMA  &= ~(1 << 1);    /* PA01 is used as TO01 output */ \
        PORT->POMA &= ~(1 << 1);    /* PA01 is normal output mode */ \
        PORT->PMCA &= ~(1 << 1);    /* PA01 digital function */ \
}while(0)

/* ToDo: You can allocate the TO02 to PA02,PA10,PB02,PB10,PC02,PC10 and PD02 pins */
#define TO02_PORT_SETTING() do{ \
        PORT->PA02CFG = 0x03;	    /* allocate TO02 to PA02 */ \
        PORT->PCLRA =  (1 << 2);    /* PA02 output low level */ \
        PORT->PMA  &= ~(1 << 2);    /* PA02 is used as TO02 output */ \
        PORT->POMA &= ~(1 << 2);    /* PA02 is normal output mode */ \
        PORT->PMCA &= ~(1 << 2);    /* PA02 digital function */ \
}while(0)

/* ToDo: You can allocate the TO03 to PA03,PA11,PB03,PB11,PC03 and PC11 pins */
#define TO03_PORT_SETTING() do{ \
        PORT->PA03CFG = 0x03;	    /* allocate TO03 to PA03 */ \
        PORT->PCLRA =  (1 << 3);    /* PA03 output low level */ \
        PORT->PMA  &= ~(1 << 3);    /* PA03 is used as TO03 output */ \
        PORT->POMA &= ~(1 << 3);    /* PA03 is normal output mode */ \
        PORT->PMCA &= ~(1 << 3);    /* PA03 digital function */ \
}while(0)

/* ToDo: You can allocate the TO04 to PA04,PA12,PB04,PB12,PC04 and PC12 pins */
#define TO04_PORT_SETTING() do{ \
        PORT->PA04CFG = 0x03;	    /* allocate TO04 to PA04 */ \
        PORT->PCLRA =  (1 << 4);    /* PA04 output low level */ \
        PORT->PMA  &= ~(1 << 4);    /* PA04 is used as TO00 output */ \
        PORT->POMA &= ~(1 << 4);    /* PA04 is normal output mode */ \
        PORT->PMCA &= ~(1 << 4);    /* PA04 digital function */ \
}while(0)

/* ToDo: You can allocate the TO05 to PA05,PA13,PB05,PB13,PC05 and PC13 pins */
#define TO05_PORT_SETTING() do{ \
        PORT->PA05CFG = 0x03;	    /* allocate TO05 to PA05 */ \
        PORT->PCLRA =  (1 << 5);    /* PA05 output low level */ \
        PORT->PMA  &= ~(1 << 5);    /* PA05 is used as TO01 output */ \
        PORT->POMA &= ~(1 << 5);    /* PA05 is normal output mode */ \
        PORT->PMCA &= ~(1 << 5);    /* PA05 digital function */ \
}while(0)

/* ToDo: You can allocate the TO06 to PA06,PA14,PB06,PB14,PC06 and PC14 pins */
#define TO06_PORT_SETTING() do{ \
        PORT->PA06CFG = 0x03;	    /* allocate TO06 to PA06 */ \
        PORT->PCLRA =  (1 << 6);    /* PA06 output low level */ \
        PORT->PMA  &= ~(1 << 6);    /* PA06 is used as TO02 output */ \
        PORT->POMA &= ~(1 << 6);    /* PA06 is normal output mode */ \
        PORT->PMCA &= ~(1 << 6);    /* PA06 digital function */ \
}while(0)

/* ToDo: You can allocate the TO07 to PA07,PA15,PB07,PB15 and PC07 pins */
#define TO07_PORT_SETTING() do{ \
        PORT->PA07CFG = 0x04;	    /* allocate TO07 to PA07 */ \
        PORT->PCLRA =  (1 << 7);    /* PA07 output low level */ \
        PORT->PMA  &= ~(1 << 7);    /* PA07 is used as TO03 output */ \
        PORT->POMA &= ~(1 << 7);    /* PA07 is normal output mode */ \
        PORT->PMCA &= ~(1 << 7);    /* PA07 digital function */ \
}while(0)

/* ToDo: You can allocate the TI00_GATE to PA03 and PB11 pins */
#define TI00_GATE_PORT_SETTING() do{ \
        PORT->PA03CFG = 0x04;	    /* allocate TI00_GATE to PA03 */ \
        PORT->PMA  |=  (1 << 3);    /* PA03 is used as TI00_GATE input */ \
        PORT->PMCA &= ~(1 << 3);    /* PA03 digital function */ \
}while(0)

/* ToDo: You can allocate the TI01_GATE to PA08 and PB13 pins */
#define TI01_GATE_PORT_SETTING() do{ \
        PORT->PA08CFG = 0x04;	    /* allocate TI01_GATE to PA08 */ \
        PORT->PMQ  |=  (1 << 8);    /* PA08 is used as TI01_GATE input */ \
        PORT->PMCQ &= ~(1 << 8);    /* PA08 digital function */ \
}while(0)

/* ToDo: You can allocate the TI02_GATE to PA09 and PB15 pins */
#define TI02_GATE_PORT_SETTING() do{ \
        PORT->PA09CFG = 0x04;	    /* allocate TI02_GATE to PA09 */ \
        PORT->PMA  |=  (1 << 9);    /* PA09 is used as TI02_GATE input */ \
        PORT->PMCA &= ~(1 << 9);    /* PA09 digital function */ \
}while(0)

/* ToDo: You can allocate the TI03_GATE to PA10 and PC00 pins */
#define TI03_GATE_PORT_SETTING() do{ \
        PORT->PA10CFG = 0x04;	    /* allocate TI03_GATE to PA10 */ \
        PORT->PMA  |=  (1 << 10);   /* PA10 is used as TI03_GATE input */ \
        PORT->PMCA &= ~(1 << 10);   /* PA10 digital function */ \
}while(0)

/* ToDo: You can allocate the TI04_GATE to PA11 and PB03 pins */
#define TI04_GATE_PORT_SETTING() do{ \
        PORT->PA11CFG = 0x04;	    /* allocate TI04_GATE to PA11 */ \
        PORT->PMA  |=  (1 << 11);   /* PA11 is used as TI04_GATE input */ \
        PORT->PMCA &= ~(1 << 11);   /* PA11 digital function */ \
}while(0)

/* ToDo: You can allocate the TI05_GATE to PA12 and PB04 pins */
#define TI05_GATE_PORT_SETTING() do{ \
        PORT->PA12CFG = 0x04;	    /* allocate TI05_GATE to PA12 */ \
        PORT->PMA  |=  (1 << 12);   /* PA12 is used as TI05_GATE input */ \
        PORT->PMCA &= ~(1 << 12);   /* PA12 digital function */ \
}while(0)

/* ToDo: You can allocate the TI06_GATE to PA05 and PB05 pins */
#define TI06_GATE_PORT_SETTING() do{ \
        PORT->PA05CFG = 0x04;	    /* allocate TI06_GATE to PA05 */ \
        PORT->PMA  |=  (1 << 5);    /* PA05 is used as TI06_GATE input */ \
        PORT->PMCA &= ~(1 << 5);    /* PA05 digital function */ \
}while(0)

/* ToDo: You can allocate the TI07_GATE to PA06 and PB09 pins */
#define TI07_GATE_PORT_SETTING() do{ \
        PORT->PA06CFG = 0x04;	    /* allocate TI07_GATE to PA06 */ \
        PORT->PMA  |=  (1 << 6);    /* PA06 is used as TI07_GATE input */ \
        PORT->PMCA &= ~(1 << 6);    /* PA06 digital function */ \
}while(0)

/* ================================================================================================================== */
/* ================                                      TMA                                         ================ */
/* ================================================================================================================== */

/**
  * @brief TAIO Port Setting (Alternative to 4 group ports)
  */

/* ToDo: You can allocate the TAIO to P01, P31, P41, or P06 with PIOR11 and PIOR10 register */
#define TAIO_PORT_SETTING() do{ \
        PORT->PB04CFG = 0x06;        /* allocate TAIO to PB04 */ \
        PORT->PB    &= ~(1 << 4);    /* PB04 output low level */ \
        PORT->PMB   &= ~(1 << 4);    /* PB04 is used as TAIO output */ \
        PORT->POMB  &= ~(1 << 4);    /* PB04 is push-pull output mode */ \
}while(0)

/* ToDo: You can allocate the TAIO to P01, P31, P41, or P06 with PIOR11 and PIOR10 register */
#define TAI_PORT_SETTING() do{ \
        PORT->PB04CFG = 0x06;        /* allocate TAI to PB04 */ \
        PORT->PMB   |=  (1 << 4);    /* P01 is used as TAIO input */ \
}while(0)

/* ToDo: You can allocate the TAO to P30, P50, or P00 with PIOR13 and PIOR12 register */
#define TAO_PORT_SETTING() do{ \
        PORT->PB06CFG = 0x06;        /* allocate TAO to PB06 */ \
        PORT->PB    &= ~(1 << 6);    /* PB06 output low level */ \
        PORT->PMB   &= ~(1 << 6);    /* PB06 is used as TAO output */ \
        PORT->POMB  &= ~(1 << 6);    /* PB06 is push-pull output mode */ \
}while(0)

/* ToDo: You can allocate the TAO to P30, P50, or P00 with PIOR13 and PIOR12 register */
#define TAON_PORT_SETTING() do{ \
        PORT->PB07CFG = 0x06;        /* allocate TAON to PB07 */ \
        PORT->PB    &= ~(1 << 7);    /* PB07 output low level */ \
        PORT->PMB   &= ~(1 << 7);    /* PB07 is used as TAO output */ \
        PORT->POMB  &= ~(1 << 7);    /* PB07 is push-pull output mode */ \
}while(0)

/* ================================================================================================================== */
/* ================                                      RTC1HZ                                      ================ */
/* ================================================================================================================== */

/**
  * @brief RTC1HZ Port Setting (RTC1HZ allocate to PA13,PB14,PC13)
  */

#define RTC1HZ_PORT_SETTING() do{ \
        PORT->PA13CFG = 0x04;       /*  allocate RTC1HZ to PA13 */ \
        PORT->PCLRA =  (1 << 13);    /* PA13 output low level */ \
        PORT->PMA  &= ~(1 << 13);    /* PA13 is used as RTC1HZ output */ \
        PORT->PMCA &= ~(1 << 13);    /* PA13 digital function */ \
}while(0)

/* ================================================================================================================== */
/* ================                                      CLKBUZ                                      ================ */
/* ================================================================================================================== */

/**
  * @brief CLKBUZ Port Setting 
  * CLKBUZ0 alternative to PA01,PA05,PA09,PA13,PB00,PB03;
  * CLKBUZ1 alternative to PA02,PA07,PA10,PA14,PB01,PC04,PD03
  */

/* ToDo: You can allocate the CLKBUZ0 to other pins */
#define CLKBUZ0_PORT_SETTING() do{ \
        PORT->PA01CFG = 0x07;       /* allocate CLKBUZ0 to PA01 */ \
        PORT->PCLRA  =  (1 << 1);   /* PA01 output low level */ \
        PORT->PMA   &= ~(1 << 1);   /* PA01 is used as CLKBUZ0 output */ \
        PORT->PMCA  &= ~(1 << 1);   /* PA01 digital function */ \
        PORT->POMA  &= ~(1 << 1);   /* PA01 CMOS output */ \
}while(0)

/* ToDo: You can allocate the CLKBUZ1 to other pins */
#define CLKBUZ1_PORT_SETTING() do{ \
        PORT->PA02CFG = 0x07;       /* allocate CLKBUZ1 to PA02 */ \
        PORT->PCLRA  =  (1 << 2);   /* PA02 output low level */ \
        PORT->PMA   &= ~(1 << 2);   /* PA02 is used as CLKBUZ1 output */ \
        PORT->PMCA  &= ~(1 << 2);   /* PA02 digital function */ \
        PORT->POMA  &= ~(1 << 2);   /* PA02 CMOS output */ \
}while(0)

/* ================================================================================================================== */
/* ================                                        ADC                                       ================ */
/* ================================================================================================================== */

/**
  * @brief ADC Port Setting
  */

/* ToDo: Please comment out the following unused ANIx setting according to your application needs. */
#define ADC_PORT_SETTING() do{ \
        PORT->PMCA |= (1 << 0);   /* Set ANI0(PA00) pin */ \
        PORT->PMCA |= (1 << 1);   /* Set ANI1(PA01) pin */ \
        PORT->PMCA |= (1 << 2);   /* Set ANI2(PA02) pin */ \
        PORT->PMCA |= (1 << 3);   /* Set ANI3(PA03) pin */ \
        PORT->PMCA |= (1 << 4);   /* Set ANI4(PA04) pin */ \
        PORT->PMCA |= (1 << 5);   /* Set ANI5(PA05) pin */ \
        PORT->PMCA |= (1 << 6);   /* Set ANI6(PA06) pin */ \
        PORT->PMCA |= (1 << 7);   /* Set ANI7(PA07) pin */ \
        PORT->PMCB |= (1 << 0);   /* Set ANI8(PB00) pin: It is necessary for ADC_VREF_AVREFP_AVREFM, used as AVREFM */ \
        PORT->PMCB |= (1 << 1);   /* Set ANI9(PB01) pin: It is necessary for ADC_VREF_AVREFP_AVREFM, used as AVREFP */ \
        PORT->PMCB |= (1 << 2);   /* Set ANI10(PB2) pin */ \
        PORT->PMCB |= (1 << 10);   /* Set ANI11(PB10) pin */ \
        PORT->PMCB |= (1 << 11);   /* Set ANI12(PB11) pin */ \
        PORT->PMCB |= (1 << 12);   /* Set ANI13(PB12) pin */ \
        PORT->PMCB |= (1 << 13);   /* Set ANI14(PB13) pin */ \
        PORT->PMCB |= (1 << 14);   /* Set ANI15(PB14) pin */ \
        PORT->PMCB |= (1 << 15);   /* Set ANI16(PB15) pin */ \
        PORT->PMCC |= (1 << 0);    /* Set ANI17(PC00) pin */ \
        PORT->PMCC |= (1 << 1);    /* Set ANI18(PC01) pin */ \
        PORT->PMCC |= (1 << 2);    /* Set ANI19(PC02) pin */ \
        PORT->PMCC |= (1 << 3);    /* Set ANI20(PC03) pin */ \
        PORT->PMCC |= (1 << 4);    /* Set ANI21(PC04) pin */ \
        PORT->PMCC |= (1 << 5);    /* Set ANI22(PC05) pin */ \
        PORT->PMCC |= (1 << 6);    /* Set ANI23(PC06) pin */ \
        PORT->PMCD |= (1 << 4);    /* Set ANI24(PD04) pin */ \
        PORT->PMCD |= (1 << 5);    /* Set ANI25(PD05) pin */ \
}while(0)

/* ================================================================================================================== */
/* ================                                        CMP                                       ================ */
/* ================================================================================================================== */

/**
  * @brief CMP Port Setting
  */

/* ToDo: You can allocate the VCOUT0 to PA00,PA06,PA11 and PB12 pins */
/* ToDo: You can allocate the VCOUT0 to PA00,PA06,PA11 and PB12 pins */
#define VCOUT0_PORT_SETTING() do { \
        PORT->PA11CFG = 0x06;     /* allocate VCOUT0 to PA11 */ \
        PORT->PMA  &= ~(1 << 11); /* VCOUT0 output to PA11 */ \
        PORT->POMA &= ~(1 << 11); /* PA11 is normal output mode */ \
        PORT->PMCA &= ~(1 << 11); /* PA11 digital function */ \
}while(0)

/* ToDo: You can allocate the VCOUT1 to PA02,PA07 and PA12 pins */
#define VCOUT1_PORT_SETTING() do { \
        PORT->PA12CFG = 0x06;     /* allocate VCOUT1 to PA12 */ \
        PORT->PMA  &= ~(1 << 12); /* VCOUT1 output to PA12 */ \
        PORT->POMA &= ~(1 << 12); /* PA12 is normal output mode */ \
        PORT->PMCA &= ~(1 << 12); /* PA12 digital function */ \
}while(0)

/* ToDo: Please comment out the PINs setting if DON'T used */
#define CMP0_PORT_SETTING() do{ \
        PORT->PMCA  |= (1 << 0);  /* Set VC0INP0(PA00) pin */ \
        PORT->PMCA  |= (1 << 1);  /* Set VC0INP1(PA02) pin */ \
        PORT->PMCA  |= (1 << 2);  /* Set VC0INP2(PA02) pin */ \
        PORT->PMCA  |= (1 << 3);  /* Set VC0INP3(PA03) pin */ \
        PORT->PMCA  |= (1 << 4);  /* Set VC0INP4(PA04) pin */ \
        PORT->PMCD  |= (1 << 4);  /* Set VC0INP5(PD04) pin */ \
        PORT->PMCA  |= (1 << 6);  /* Set VC0INN0(PA06) pin */ \
        PORT->PMCA  |= (1 << 7);  /* Set VC0INN1(PA07) pin */ \
        PORT->PMCA  |= (1 << 5);  /* Set VC0INN2(PA05) pin */ \
        VCOUT0_PORT_SETTING();    /* ToDo: Please delete me if you don't output VCOUT0 signal to port */ \
}while(0)

/* ToDo: Please comment out the PINs setting if DON'T used */
#define CMP1_PORT_SETTING() do{ \
        PORT->PMCB  |= (1 << 2);  /* Set VC1INP0(PB02) pin */ \
        PORT->PMCB  |= (1 << 10); /* Set VC1INP1(PB10) pin */ \
        PORT->PMCB  |= (1 << 11); /* Set VC1INP2(PB11) pin */ \
        PORT->PMCB  |= (1 << 12); /* Set VC1INP3(PB12) pin */ \
        PORT->PMCC  |= (1 << 0);  /* Set VC1INP4(PC00) pin */ \
        PORT->PMCC  |= (1 << 1);  /* Set VC1INP5(PC01) pin */ \
        PORT->PMCB  |= (1 << 13); /* Set VC1INN0(PB13) pin */ \
        PORT->PMCC  |= (1 << 2);  /* Set VC1INN1(PC02) pin */ \
        PORT->PMCA  |= (1 << 5);  /* Set VC1INN2(PA05) pin */ \
        VCOUT1_PORT_SETTING();    /* ToDo: Please delete me if you don't output VCOUT1 signal to port */ \
}while(0)

/* ================================================================================================================== */
/* ================                                        DAC                                       ================ */
/* ================================================================================================================== */

/**
  * @brief DAC Port Setting (Alternative to fixed port)
  */

#define DAC0_PORT_SETTING() do { \
        PORT->PMCA |= (1 << 5);   /* DAC0 output to PA05 */ \
}while(0)

/* ================================================================================================================== */
/* ================                                        OPA                                       ================ */
/* ================================================================================================================== */

/**
  * @brief OPA Port Setting (Alternative to fixed port)
  */

#define OPA0O_PORT_SETTING() do { \
        PORT->PMCD |= (1 << 4);   /* PGA0O output to PD04 */ \
}while(0)

#define OPA0DA_PORT_SETTING() do { \
        PORT->PMCA |= (1 << 4);  /* OPA0DA input from PA04 */ \
}while(0)

#define OPA0FB_PORT_SETTING() do { \
        PORT->PMCD |= (1 << 5);  /* OPA0FB input from PD05 */ \
}while(0)

/* ================================================================================================================== */
/* ================                                       SCI0                                       ================ */
/* ================================================================================================================== */

/**
  * @brief UART0 Port Setting (Can alternative to other pins)
  */

/* ToDo: You can allocate the TXD0 to other pins */
#define TXD0_PORT_SETTING() do{ \
        PORT->PB09CFG = 0x01;        /* allocate TXD0 to PB09 */ \
        PORT->PSETB =  (1 << 9);     /* PB09 output high level */ \
        PORT->PMB  &= ~(1 << 9);     /* PB09 is used as TXD0 output */ \
        PORT->POMB &= ~(1 << 9);     /* PB09 is normal output mode */ \
        PORT->PMCB &= ~(1 << 9);     /* PB09 digital function */ \
}while(0)

/* ToDo: You can allocate the RXD0 to other pins */
#define RXD0_PORT_SETTING() do{ \
        PORT->PD03CFG = 0x01;        /* allocate RXD0 to PD03 */ \
        PORT->PMD  |=  (1 << 3);     /* PD03 is used as RXD0 input */ \
}while(0)

/**
  * @brief SPI00 Port Setting (Can alternative to other pins)
  */

/* ToDo: You can allocate the SS00 to other pins */
#define SS00_PORT_SETTING() do{ \
        PORT->PA11CFG = 0x01;       /* allocate SS00 to PA11 */ \
        PORT->PMA  |=  (1 << 11);   /* PA11 is used as SS00 input */ \
        PORT->PUA  |=  (1 << 11);   /* PA11 pull up resistor enable */ \
        PORT->PMCA &= ~(1 << 11);   /* PA11 digital function */ \
}while(0)

/* ToDo: SS00 Alternative to fixed port */
#define SS00_PORT_SET() // do{ \
        PORT->PSETA = (1 << 11);      /* PA11 output high level */ \
}while(0)

/* ToDo: SS00 Alternative to fixed port */
#define SS00_PORT_CLR() // do{ \
        PORT->PCLRA = (1 << 11);      /* PA11 output low level */ \
}while(0)

/* ToDo: SS00 Alternative to fixed port  */
#define SCLKI00_PORT_SETTING() do{ \
        PORT->PB08CFG = 0x01;        /* allocate SCLKO00 to PB08 */ \
        PORT->PMB  |=  (1 << 8);     /* PB08 is used as SCLK00 input */ \
        PORT->PMCB &= ~(1 << 8);     /* PB08 digital function */ \
}while(0)

/* ToDo: You can allocate the SCLKO00 to other pins */ 
#define SCLKO00_PORT_SETTING() do{ \
        PORT->PB08CFG = 0x01;        /* allocate SCLKO00 to PB08 */ \
        PORT->PSETB =  (1 << 8);    /* PB08 output high level */ \
        PORT->PMB  &= ~(1 << 8);    /* PB08 is used as SCLK00 output */ \
        PORT->POMB &= ~(1 << 8);    /* PB08 is normal output mode */ \
        PORT->PMCB &= ~(1 << 8);    /* PB08 digital function */ \
}while(0)

/* ToDo: You can allocate the SDO00 to other pins */
#define SDO00_PORT_SETTING() do{ \
        PORT->PB09CFG = 0x01;        /* allocate SDO00 to PB09 */ \
        PORT->PSETB =  (1 << 9);     /* PB09 output high level */ \
        PORT->PMB  &= ~(1 << 9);     /* PB09 is used as TXD0 output */ \
        PORT->POMB &= ~(1 << 9);     /* PB09 is normal output mode */ \
        PORT->PMCB &= ~(1 << 9);     /* PB09 digital function */ \
}while(0)

/* ToDo: You can allocate the SDI00 to other pins */
#define SDI00_PORT_SETTING() do{ \
        PORT->PB07CFG = 0x01;        /* allocate SDI00 to PB07 */ \
        PORT->PMB  |=  (1 << 7);     /* PB07 is used as SDI00 input */ \
        PORT->PMCB &= ~(1 << 7);     /* PB07 digital function */ \
}while(0)

/**
  * @brief IIC00 Port Setting (Can alternative to other pins)
  */

/* ToDo: You can allocate the SCL00 to other pins */
#define SCL00_PORT_SETTING() do{ \
        PORT->PB08CFG = 0x01;        /* allocate SCL00 to PB08 */ \
        PORT->PSETB =  (1 << 8);     /* PB08 output high level */ \
        PORT->PMB  &= ~(1 << 8);     /* PB08 is used as SCL00 output */ \
        PORT->POMB |=  (1 << 8);     /* PB08 is N-ch open-drain output mode */ \
        PORT->PMCB &= ~(1 << 8);     /* PB08 digital function */ \
}while(0)

/* ToDo: You can allocate the SDA00 to other pins */
#define SDA00_PORT_SETTING() do{ \
        PORT->PB07CFG = 0x01;        /* allocate SDA00 to PB07 */ \
        PORT->PSETB =  (1 << 7);     /* PB07 output high level */ \
        PORT->PMB  &= ~(1 << 7);     /* PB07 is used as SDA00 in/out */ \
        PORT->POMB |=  (1 << 7);     /* PB07 is N-ch open-drain output mode */ \
        PORT->PMCB &= ~(1 << 7);     /* PB07 digital function */ \
}while(0) 

/**
  * @brief SPI01 Port Setting (Alternative to fixed port)
  */

#define SS01_PORT_SETTING() do{ \
        PORT->PB14CFG = 0x00;         /* PB14 default GPIO function */ \
        PORT->PMB  |=  (1 << 14);     /* PB14 is used as SS01 output */ \
        PORT->PUB  |=  (1 << 14);     /* PB14 pull up resistor enable */ \
        PORT->PMCB &= ~(1 << 14);     /* PB14 digital function */ \
}while(0)

#define SS01_PORT_SET() // do{ \
        PORT->PSETB = (1 << 14);      /* PB14 output high level */ \
}while(0)

#define SS01_PORT_CLR() // do{ \
        PORT->PCLRB = (1 << 14);      /* PB14 output low level */ \
}while(0)

#define SCLKI01_PORT_SETTING() do{ \
        PORT->PC06CFG = 0x01;        /* PC06 default Alternate function */ \
        PORT->PMC  |=  (1 << 6);     /* PC06 is used as SCLK00 input */ \
        PORT->PMCC &= ~(1 << 6);     /* PC06 digital function */ \
}while(0)

#define SCLKO01_PORT_SETTING() do{ \
        PORT->PC06CFG = 0x01;        /* PC06 default Alternate function */ \
        PORT->PSETC =  (1 << 6);     /* PC06 output high level */ \
        PORT->PMC  &= ~(1 << 6);     /* PC06 is used as SCLK00 output */ \
        PORT->POMC &= ~(1 << 6);     /* PC06 is normal output mode */ \
        PORT->PMCC &= ~(1 << 6);     /* PC06 digital function */ \
}while(0)

#define SDO01_PORT_SETTING() do{ \
        PORT->PC08CFG = 0x01;        /* PC08 default Alternate function */ \
        PORT->PSETC =  (1 << 8);     /* PC08 output high level */ \
        PORT->PMC  &= ~(1 << 8);     /* PC08 is used as SDO01 output */ \
        PORT->POMC &= ~(1 << 8);     /* PC08 is normal output mode */ \
        PORT->PMCC &= ~(1 << 8);     /* PC08 digital function */ \
}while(0)

#define SDI01_PORT_SETTING() do{ \
        PORT->PC07CFG = 0x01;        /* PC07 default Alternate function */ \
        PORT->PMC  |=  (1 << 7);     /* PC07 is used as SDI01 input */ \
        PORT->PMCC &= ~(1 << 7);     /* PC07 digital function */ \
}while(0)

/**
  * @brief IIC01 Port Setting (Alternative to fixed port)
  */

#define SCL01_PORT_SETTING() do{ \
        PORT->PC06CFG = 0x01;        /* PC06 default Alternate function */ \
        PORT->PSETC =  (1 << 6);     /* PC06 output high level */ \
        PORT->PMC  &= ~(1 << 6);     /* PC06 is used as SCL01 output */ \
        PORT->POMC |=  (1 << 6);     /* PC06 is N-ch open-drain output mode */ \
        PORT->PMCC &= ~(1 << 6);     /* PC06 digital function */ \
}while(0)

#define SDA01_PORT_SETTING() do{ \
        PORT->PC07CFG = 0x01;        /* PC07 default Alternate function */ \
        PORT->PSETC =  (1 << 7);     /* PC07 output high level */ \
        PORT->PMC  &= ~(1 << 7);     /* PC07 is used as SDA01 in/out */ \
        PORT->POMC |=  (1 << 7);     /* PC07 is N-ch open-drain output mode */ \
        PORT->PMCC &= ~(1 << 7);     /* PC07 digital function */ \
}while(0)

/* ================================================================================================================== */
/* ================                                       SCI1                                       ================ */
/* ================================================================================================================== */

/**
  * @brief UART1 Port Setting (Can alternative to other pins)
  */

/* ToDo: You can allocate the TXD1 to other pins */
#define TXD1_PORT_SETTING() do{ \
        PORT->PB10CFG = 0x01;        /* allocate TXD1 to PB10 */ \
        PORT->PSETC =  (1 << 10);    /* PB10 output high level */ \
        PORT->PMC  &= ~(1 << 10);    /* PB10 is used as TXD1 output */ \
        PORT->POMC &= ~(1 << 10);    /* PB10 is normal output mode */ \
        PORT->PMCC &= ~(1 << 10);    /* PB10 digital function */ \
}while(0)

/* ToDo: You can allocate the RXD1 to other pins with RXD1PCFG register */
#define RXD1_PORT_SETTING() do{ \
        PORT->PB11CFG = 0x01;        /* allocate RXD1 to PB11 */ \
        PORT->PMB  |=  (1 << 11);    /* PB11 is used as RXD1 input */ \
        PORT->PMCB &= ~(1 << 11);    /* PB11 digital function */ \
}while(0)

/**
  * @brief SPI10 Port Setting (Can alternative to other pins)
  */

/* ToDo: You can allocate the SS10 to PA05 or PC14 pins */
#define SS10_PORT_SETTING() do{ \
        PORT->PC14CFG = 0x01;         /* PC14 default GPIO function */ \
        PORT->PMC  |=  (1 << 14);     /* PC14 is used as SS10 input */ \
        PORT->PUC  |=  (1 << 14);     /* PC14 pull up resistor enable */ \
        PORT->PMCC &= ~(1 << 14);     /* PC14 digital function */ \
}while(0)

#define SS10_PORT_SET() // do{ \
        PORT->PSETC =  (1 << 14);      /* PC14 output high level */ \
}while(0)

#define SS10_PORT_CLR() // do{ \
        PORT->PCLRC = (1 << 14);       /* PC14 output low level */ \
}while(0)

/* ToDo: You can allocate the SCLK10 to other pins */
#define SCLKI10_PORT_SETTING() do{ \
        PORT->PC13CFG = 0x01;       /* PC13 default Alternate function */ \
        PORT->PMC  |=  (1 << 13);   /* PC13 is used as SCLK10 input */ \
        PORT->PMCC &= ~(1 << 13);   /* PC13 digital function */ \
}while(0)

#define SCLKO10_PORT_SETTING() do{ \
        PORT->PC13CFG = 0x01;       /* PC13 default Alternate function */ \
        PORT->PSETC =  (1 << 13);   /* PC13 output high level */ \
        PORT->PMC  &= ~(1 << 13);   /* PC13 is used as SCLK10 output */ \
        PORT->POMC &= ~(1 << 13);   /* PC13 is normal output mode */ \
        PORT->PMCC &= ~(1 << 13);   /* PC13 digital function */ \
}while(0)

/* ToDo: You can allocate the SDO10 to other pins */
#define SDO10_PORT_SETTING() do{ \
        PORT->PC04CFG = 0x01;        /* allocate SDO10 to PC04 */ \
        PORT->PSETC =  (1 << 4);     /* PC04 output high level */ \
        PORT->PMC  &= ~(1 << 4);     /* PC04 is used as SDO10 output */ \
        PORT->POMC &= ~(1 << 4);     /* PC04 is normal output mode */ \
        PORT->PMCC &= ~(1 << 4);     /* PC04 digital function */ \
}while(0)

/* ToDo: You can allocate the SDI10 to other pins with SDI10PCFG register */
#define SDI10_PORT_SETTING() do{ \
        PORT->PC05CFG = 0x01;        /* allocate SDI10 to PC05 */ \
        PORT->PMC  |=  (1 << 5);     /* PC05 is used as SDI10 input */ \
        PORT->PMCC &= ~(1 << 5);     /* PC05 digital function */ \
}while(0)

/**
  * @brief IIC10 Port Setting (Can alternative to other pins)
  */

#define SCL10_PORT_SETTING() do{ \
        PORT->PB13CFG = 0x01;       /* PB13 default Alternate function */ \
        PORT->PB   |=  (1 << 13);   /* PB13 output  */ \
        PORT->PMB  &= ~(1 << 13);   /* PB13 is used as SCL10 output */ \
        PORT->POMB |=  (1 << 13);   /* PB13 is N-ch open-drain output mode */ \
        PORT->PMCB &= ~(1 << 13);   /* PB13 digital function */ \
}while(0)

/* ToDo: You can allocate the SDA10 to other pins */
#define SDA10_PORT_SETTING() do{ \
        PORT->PB11CFG = 0x01;        /* allocate SDA10 to PB11 */ \
        PORT->PSETB =  (1 << 11);    /* PB11 output high level */ \
        PORT->PMB  &= ~(1 << 11);    /* PB11 is used as SDA10 in/out */ \
        PORT->POMB |=  (1 << 11);    /* PB11 is N-ch open-drain output mode */ \
        PORT->PMCB &= ~(1 << 11);    /* PB11 digital function */ \
}while(0)

/**
  * @brief SPI11 Port Setting (Alternative to fixed port)
  */

#define SS11_PORT_SETTING() do{ \
        PORT->PA12CFG = 0x01;         /* PA12 default GPIO function */ \
        PORT->PMA  |=  (1 << 12);     /* PA12 is used as SS11 input */ \
        PORT->PUA  |=  (1 << 12);     /* PA12 pull up resistor enable */ \
        PORT->PMCA &= ~(1 << 12);     /* PA12 digital function */ \
}while(0)

#define SS11_PORT_SET() // do{ \
        PORT->PSETA =  (1 << 12);     /* PA12 output high level */ \
}while(0)

#define SS11_PORT_CLR() // do{ \
        PORT->PCLRA = (1 << 12);      /* PA12 output low level */ \
}while(0)

#define SCLKI11_PORT_SETTING() do{ \
        PORT->PB03CFG = 0x01;        /* PB03 default Alternate function */ \
        PORT->PMB  |=  (1 << 3);     /* PB03 is used as SCLK11 input */ \
        PORT->PMCB &= ~(1 << 3);     /* PB03 digital function */ \
}while(0)

#define SCLKO11_PORT_SETTING() do{ \
        PORT->PB03CFG = 0x01;        /* PB03 default Alternate function */ \
        PORT->PSETB =  (1 << 3);     /* PB03 output high level */ \
        PORT->PMB  &= ~(1 << 3);     /* PB03 is used as SCLK11 output */ \
        PORT->POMB &= ~(1 << 3);     /* PB03 is normal output mode */ \
        PORT->PMCB &= ~(1 << 3);     /* PB03 digital function */ \
}while(0)

#define SDO11_PORT_SETTING() do{ \
        PORT->PB05CFG = 0x01;        /* PB05 default Alternate function */ \
        PORT->PSETB =  (1 << 5);     /* PB05 output high level */ \
        PORT->PMB  &= ~(1 << 5);     /* PB05 is used as SDO11 output */ \
        PORT->POMB &= ~(1 << 5);     /* PB05 is normal output mode */ \
        PORT->PMCB &= ~(1 << 5);     /* PB05 digital function */ \
}while(0)

#define SDI11_PORT_SETTING() do{ \
        PORT->PB04CFG = 0x01;        /* PB04 default Alternate function */ \
        PORT->PMB  |=  (1 << 4);     /* PB04 is used as SDI11 input */ \
        PORT->PMCB &= ~(1 << 4);     /* PB04 digital function */ \
}while(0)

/**
  * @brief IIC11 Port Setting (Alternative to fixed port)
  */

#define SCL11_PORT_SETTING() do{ \
        PORT->PB03CFG = 0x00;        /* PB03 default Alternate function */ \
        PORT->PSETB =  (1 << 3);     /* PB03 output high level */ \
        PORT->PMB  &= ~(1 << 3);     /* PB03 is used as SCL11 output */ \
        PORT->POMB |=  (1 << 3);     /* PB03 is N-ch open-drain output mode */ \
        PORT->PMCB &= ~(1 << 3);     /* PB03 digital function */ \
}while(0)

#define SDA11_PORT_SETTING() do{ \
        PORT->PB04CFG = 0x01;        /* PB04 default Alternate function */ \
        PORT->PSETB =  (1 << 4);     /* PB04 output high level */ \
        PORT->PMB  &= ~(1 << 4);     /* PB04 is used as SDA11 in/out */ \
        PORT->POMB |=  (1 << 4);     /* PB04 is N-ch open-drain output mode */ \
        PORT->PMCB &= ~(1 << 4);     /* PB04 digital function */ \
}while(0)

/* ================================================================================================================== */
/* ================                                       SCI2                                       ================ */
/* ================================================================================================================== */

/**
  * @brief UART2 Port Setting (Can alternative to other pins) 
  */

/* ToDo: You can allocate the TXD2 to other pins */
#define TXD2_PORT_SETTING() do{ \
        PORT->PC10CFG = 0x01;        /* allocate TXD2 to PC10 */ \
        PORT->PSETC =  (1 << 10);    /* PC10 output high level */ \
        PORT->PMC  &= ~(1 << 10);    /* PC10 is used as TXD2 output */ \
        PORT->POMC &= ~(1 << 10);    /* PC10 is normal output mode */ \
        PORT->PMCC &= ~(1 << 10);    /* PC10 digital function */ \
}while(0)

/* ToDo: You can allocate the RXD2 to other pins */
#define RXD2_PORT_SETTING() do{ \
        PORT->PC11CFG = 0x01;      /* allocate RXD2 to PC11 */ \
        PORT->PMC  |=  (1 << 11);    /* PC11 is used as RXD2 input */ \
        PORT->PMCC &= ~(1 << 11);    /* PC11 digital function */ \
}while(0)

/**
  * @brief SPI20 Port Setting (Can alternative to other pins)
  */

#define SS20_PORT_SETTING() do{ \
        PORT->PA06CFG = 0x01;        /* PA06 default GPIO function */ \
        PORT->PMA  |=  (1 << 6);     /* PA06 is used as SS20 input */ \
        PORT->PUA  |=  (1 << 6);     /* PA06 pull up resistor enable */ \
        PORT->PMCA &= ~(1 << 6);     /* PA06 digital function */ \
}while(0)

#define SS20_PORT_SET() //do{ \
        PORT->PSETA = (1 << 6);      /* PA06 output high level */ \
}while(0)

#define SS20_PORT_CLR() //do{ \
        PORT->PCLRA = (1 << 6);      /* PA06 output low level */ \
}while(0)

/* ToDo: You can allocate the SCLKI20 to other pins */
#define SCLKI20_PORT_SETTING() do{ \
        PORT->PB01CFG = 0x01;    /* allocate SCLK20 to PB01 */ \
        PORT->PMB  |=  (1 << 1);     /* PB01 is used as SCLK20 input */ \
        PORT->PMCB &= ~(1 << 1);     /* PB01 digital function */ \
}while(0)

/* ToDo: You can allocate the SCLKO20 to other pins */
#define SCLKO20_PORT_SETTING() do{ \
        PORT->PB01CFG = 0x01;       /* allocate SCLK20 to PB01 */ \
        PORT->PSETB =  (1 << 1);    /* PB01 output high level */ \
        PORT->PMB  &= ~(1 << 1);    /* PB01 is used as SCLK20 output */ \
        PORT->POMB &= ~(1 << 1);    /* PB01 is normal output mode */ \
        PORT->PMCB &= ~(1 << 1);    /* PB01 digital function */ \
}while(0)

/* ToDo: You can allocate the SDO20 to other pins */
#define SDO20_PORT_SETTING() do{ \
        PORT->PC10CFG = 0x01;       /* allocate SDO20 to PC10 */ \
        PORT->PSETC =  (1 << 10);   /* PC10 output high level */ \
        PORT->PMC  &= ~(1 << 10);   /* PC10 is used as SDO20 output */ \
        PORT->POMC &= ~(1 << 10);   /* PC10 is normal output mode */ \
        PORT->PMCC &= ~(1 << 10);   /* PC10 digital function */ \
}while(0)

/* ToDo: You can allocate the SDI20 to other pins with SDI20PCFG register */
#define SDI20_PORT_SETTING() do{ \
        PORT->PC11CFG = 0x01;      /* allocate SDI20 to PC11 */ \
        PORT->PMC  |=  (1 << 11);  /* PC11 is used as SDI20 input */ \
        PORT->PMCC &= ~(1 << 11);  /* PC11 digital function */ \
}while(0)

/**
  * @brief IIC20 Port Setting (Can alternative to other pins)
  */

/* ToDo: You can allocate the SCL20 to other pins */
#define SCL20_PORT_SETTING() do{ \
        PORT->PB01CFG = 0x01;       /* allocate SCL20 to PB01 */ \
        PORT->PSETB =  (1 << 1);    /* PB01 output high level */ \
        PORT->PMB  &= ~(1 << 1);    /* PB01 is used as SCL20 output */ \
        PORT->POMB |=  (1 << 1);    /* PB01 is N-ch open-drain output mode */ \
        PORT->PMCB &= ~(1 << 1);    /* PB01 digital function */ \
}while(0)

#define SDA20_PORT_SETTING() do{ \
        PORT->PB15CFG = 0x01;        /* allocate SDA20 to PB15 */ \
        PORT->PSETB =  (1 << 5);    /* PB15 output high level */ \
        PORT->PMB  &= ~(1 << 5);    /* PB15 is used as SDA20 in/out */ \
        PORT->POMB |=  (1 << 5);    /* PB15 is N-ch open-drain output mode */ \
        PORT->PMCB &= ~(1 << 5);    /* PB15 digital function */ \
}while(0)

/**
  * @brief SPI21 Port Setting (Alternative to fixed port)
  */

#define SS21_PORT_SETTING() do{ \
        PORT->PC00CFG = 0x01;        /* PC00 default GPIO function */ \
        PORT->PSETC =  (1 << 0);     /* PC00 output high level */ \
        PORT->PMC  &= ~(1 << 0);     /* PC00 is used as SS21 output */ \
        PORT->PMCC &= ~(1 << 0);     /* PC00 digital function */ \
}while(0)

#define SS21_PORT_SET() //do{ \
        PORT->PSETC = (1 << 0);      /* PC00 output high level */ \
}while(0)

#define SS21_PORT_CLR() //do{ \
        PORT->PCLRC = (1 << 0);      /* PC00 output low level */ \
}while(0)

#define SCLKI21_PORT_SETTING() do{ \
        PORT->PC01CFG = 0x01;       /* PC01 default Alternate function */ \
        PORT->PMC  |=  (1 << 1);    /* PC01 is used as SCLK21 input */ \
        PORT->PMCC &= ~(1 << 1);    /* PC01 digital function */ \
}while(0)

#define SCLKO21_PORT_SETTING() do{ \
        PORT->PC01CFG = 0x01;       /* PC01 default Alternate function */ \
        PORT->PSETC =  (1 << 1);    /* PC01 output high level */ \
        PORT->PMC  &= ~(1 << 1);    /* PC01 is used as SCLK21 output */ \
        PORT->POMC &= ~(1 << 1);    /* PC01 is normal output mode */ \
        PORT->PMCC &= ~(1 << 1);    /* PC01 digital function */ \
}while(0)

#define SDO21_PORT_SETTING() do{ \
        PORT->PC03CFG = 0x01;       /* PC03 default Alternate function */ \
        PORT->PSETC =  (1 << 3);    /* PC03 output high level */ \
        PORT->PMC  &= ~(1 << 3);    /* PC03 is used as SDO21 output */ \
        PORT->POMC &= ~(1 << 3);    /* PC03 is normal output mode */ \
        PORT->PMCC &= ~(1 << 3);    /* PC03 digital function */ \
}while(0)

#define SDI21_PORT_SETTING() do{ \
        PORT->PC02CFG = 0x01;        /* PC02 default Alternate function */ \
        PORT->PMC  |=  (1 << 2);     /* PC02 is used as SDI21 input */ \
        PORT->PMCC &= ~(1 << 2);     /* PC02 digital function */ \
}while(0)

/**
  * @brief IIC21 Port Setting (Alternative to fixed port)
  */

#define SCL21_PORT_SETTING() do{ \
        PORT->PC01CFG = 0x01;       /* PC01 default Alternate function */ \
        PORT->PSETC =  (1 << 1);    /* PC01 output high level */ \
        PORT->PMC  &= ~(1 << 1);    /* PC01 is used as SCL21 output */ \
        PORT->POMC |=  (1 << 1);    /* PC01 is N-ch open-drain output mode */ \
        PORT->PMCC &= ~(1 << 1);    /* PC01 digital function */ \
}while(0)

#define SDA21_PORT_SETTING() do{ \
        PORT->PC02CFG = 0x01;       /* PC02 default Alternate function */ \
        PORT->PSETC =  (1 << 2);    /* PC02 output high level */ \
        PORT->PMC  &= ~(1 << 2);    /* PC02 is used as SDA21 in/out */ \
        PORT->POMC |=  (1 << 2);    /* PC02 is N-ch open-drain output mode */ \
        PORT->PMCC &= ~(1 << 2);    /* PC02 digital function */ \
}while(0)

/* ================================================================================================================== */
/* ================                                       SPI                                        ================ */
/* ================================================================================================================== */

/**
  * @brief SPI Port Setting (Can alternative to other pins) 
  */

/* ToDo: Please define one of the following macro and comment out others accroding to your application */
//#define SPIHS0_SLAVE_PORT
#define SPIHS0_MASTER_PORT
#if ((defined(SPIHS0_SLAVE_PORT) & defined(SPIHS0_MASTER_PORT)))
    #error "Multi-functions declared of SPIHS0."
#endif

#ifdef SPIHS0_SLAVE_PORT
#define NSS0_PORT_SETTING() do{ \
        PORT->PB12CFG = 0x05;        /* SCK0 alternate to PB12 */ \
        PORT->PMB  |=  (1 << 12);    /* PB12 is used as NSS0 input */ \
        PORT->PMCB &= ~(1 << 12);    /* PB12 digital function */ \
}while(0)

#define NSS0_PORT_SET() do{ \
        __NOP(); \
}while(0)

#define NSS0_PORT_CLR() do{ \
        __NOP(); \
}while(0)

#define SCK0_PORT_SETTING() do{ \
        PORT->PB13CFG = 0x05;        /* SCK0 alternate to PB13 */ \
        PORT->PMB  |=  (1 << 13);    /* PB13 is used as SCK0 input */ \
        PORT->PMCB &= ~(1 << 13);    /* PB13 digital function */ \
}while(0)

#define MOSI0_PORT_SETTING() do{ \
        PORT->PB15CFG = 0x05;       /* MOSI0 alternate to PB15 */ \
        PORT->PMB  |=  (1 << 15);   /* PB15 is used as MOSI input */ \
        PORT->PMCB &= ~(1 << 15);   /* PB15 digital function */ \
}while(0)

#define MISO0_PORT_SETTING() do{ \
        PORT->PB14CFG = 0x05;       /* MISO0 alternate to PB14 */ \
        PORT->PCLRB =  (1 << 14);   /* PB14 output low level */ \
        PORT->PMB  &= ~(1 << 14);   /* PB14 is used as MISO output */ \
        PORT->POMB &= ~(1 << 14);   /* PB14 is normal output mode */ \
        PORT->PMCB &= ~(1 << 14);   /* PB14 digital function */ \
}while(0)
#endif

#ifdef SPIHS0_MASTER_PORT
#define NSS0_PORT_SETTING() do{ \
        PORT->PB12CFG = 0x00;       /* SCK0 alternate to PB12 */ \
        PORT->PSETB =  (1 << 12);   /* PB12 output high level */ \
        PORT->PMB  &= ~(1 << 12);   /* PB12 is used as NSS0 output */ \
        PORT->PMCB &= ~(1 << 12);   /* PB12 digital function */ \
}while(0)
//        PORT->PB12CFG = 0x05;       /* SCK0 alternate to PB12 */ \

#define NSS0_PORT_SET() do{ \
        PORT->PSETB =  (1 << 12);   /* PB12 output high level */ \
}while(0)

#define NSS0_PORT_CLR() do{ \
        PORT->PCLRB =  (1 << 12);   /* PB12 output low level */ \
}while(0)

#define SCK0_PORT_SETTING() do{ \
        PORT->PB13CFG = 0x05;       /* SCK0 alternate to PB13 */ \
        PORT->PCLRB =  (1 << 13);   /* PB13 output low level */ \
        PORT->PMB  &= ~(1 << 13);   /* PB13 is used as SCK output */ \
        PORT->POMB &= ~(1 << 13);   /* PB13 is normal output mode */ \
        PORT->PMCB &= ~(1 << 13);   /* PB13 digital function */ \
}while(0)

#define MOSI0_PORT_SETTING() do{ \
        PORT->PB15CFG = 0x05;       /* MOSI0 alternate to PB15 */ \
        PORT->PCLRB =  (1 << 15);   /* PB15 output low level */ \
        PORT->PMB  &= ~(1 << 15);   /* PB15 is used as MOSI output */ \
        PORT->POMB &= ~(1 << 15);   /* PB15 is normal output mode */ \
        PORT->PMCB &= ~(1 << 15);   /* PB15 digital function */ \
}while(0)

#define MISO0_PORT_SETTING() do{ \
        PORT->PB14CFG = 0x05;  /* MISO0 alternate to PB14 */ \
        PORT->PMB  |=  (1 << 14);   /* PB14 is used as MISO input */ \
        PORT->PMCB &= ~(1 << 14);   /* PB14 digital function */ \
}while(0)
#endif


/* ================================================================================================================== */
/* ================                                       IICA                                       ================ */
/* ================================================================================================================== */

/**
  * @brief IICA0 Port Setting (Can alternative to other pins) 
  */

/* ToDo: You can allocate the SCLA0 to other pins with SCLA0PCFG register */
#define SCLA0_PORT_SETTING() do{ \
        PORT->PA11CFG = 0x02;       /* allocate SCLA0 to PA11 */ \
        PORT->PCLRA =  (1 << 11);   /* PA11 output low level */ \
        PORT->PUA  |=  (1 << 11);   /* PA11 pull up enable */ \
        PORT->PMA  &= ~(1 << 11);   /* PA11 is used as SCLA0 in/out */ \
        PORT->POMA &= ~(1 << 11);   /* PA11 N-Channel open output */ \
        PORT->PMCA &= ~(1 << 11);   /* PA11 digital function */ \
}while(0)

/* ToDo: You can allocate the SDAA0 to other pins with SDAA0PCFG register */
#define SDAA0_PORT_SETTING() do{ \
        PORT->PA12CFG = 0x02;       /* allocate SDAA0 to PA12 */ \
        PORT->PCLRA =  (1 << 12);   /* PA12 output low level */ \
        PORT->PUA  |=  (1 << 12);   /* PA12 pull up enable */ \
        PORT->PMA  &= ~(1 << 12);   /* PA12 is used as SDAA0 in/out */ \
        PORT->POMA &= ~(1 << 12);   /* PA12 N-Channel open output */ \
        PORT->PMCA &= ~(1 << 12);   /* PA12 digital function */ \
}while(0)

/* ================================================================================================================== */
/* ================                                       INTP                                       ================ */
/* ================================================================================================================== */
/**
  * @brief INTP Port Setting 
  */
/* ToDo: You can allocate the INTP0 to PA00~PA15 pins with INTP0PCFG register */
#define INTP0_PORT_SETTING() do{ \
        PORT->INTP0PCFG = 0x00;     /* allocate INTP0 to PA00 */ \
        PORT->PA00CFG = 0x00;       /* PA00 default Alternate function */ \
        PORT->PMA  |=  (1 << 0);    /* PA00 is used as INTP0 input */ \
        PORT->PMCA &= ~(1 << 0);    /* PA00 digital function */ \
}while(0)

/* ToDo: You can allocate the INTP1 to PB00~07 pins with INTP1PCFG register */
#define INTP1_PORT_SETTING() do{ \
        PORT->INTP1PCFG = 0x00;     /* allocate INTP1 to PB00 */ \
        PORT->PB00CFG = 0x00;       /* PB00 default Alternate function */ \
        PORT->PMB  |=  (1 << 0);    /* PB00 is used as INTP1 input */ \
        PORT->PMCB &= ~(1 << 0);    /* PB00 digital function */ \
}while(0)

/* ToDo: You can allocate the INTP2 to PC00~PC13,PH03,PH04 pins with INTP2PCFG register */
#define INTP2_PORT_SETTING() do{ \
        PORT->INTP2PCFG = 0x00;     /* allocate INTP2 to PC00 */ \
        PORT->PC00CFG = 0x00;       /* PC00 default Alternate function */ \
        PORT->PMC  |=  (1 << 0);    /* PC00 is used as INTP2 input */ \
        PORT->PMCC &= ~(1 << 0);    /* PC00 digital function */ \
}while(0)

/* ToDo: You can allocate the INTP3 to PD00~PD02,PB08,PH00~PH02 pins with INTP3PCFG register */
#define INTP3_PORT_SETTING() do{ \
        PORT->INTP3PCFG = 0x00;     /* allocate INTP3 to PD00 */ \
        PORT->PD00CFG = 0x00;       /* PD00 default Alternate function */ \
        PORT->PMD  |=  (1 << 0);    /* PD00 is used as INTP3 input */ \
        PORT->PMCD &= ~(1 << 0);    /* PD00 digital function */ \
}while(0)

/* ToDo: You can allocate the INTP4 to PC14,PD04~PD09 pins with INTP4PCFG register */
#define INTP4_PORT_SETTING() do{ \
        PORT->INTP4PCFG = 0x00;     /* allocate INTP2 to PC14 */ \
        PORT->PC14CFG = 0x00;       /* PC14 default Alternate function */ \
        PORT->PMC  |=  (1 << 14);   /* PC14 is used as INTP2 input */ \
        PORT->PMCC &= ~(1 << 14);   /* PC14 digital function */ \
}while(0)

/* ToDo: You can allocate the INTP5 to PD03,PB09~PB15 pins with INTP5PCFG register */
#define INTP5_PORT_SETTING() do{ \
        PORT->INTP5PCFG = 0x00;     /* allocate INTP3 to PD03 */ \
        PORT->PD03CFG = 0x00;       /* PD03 default Alternate function */ \
        PORT->PMD  |=  (1 << 3);    /* PD03 is used as INTP3 input */ \
        PORT->PMCD &= ~(1 << 3);    /* PD03 digital function */ \
}while(0)

/** @} */ /* End of group Peripherals_Port_Setting_Definations */

#endif
