/***********************************************************************************************************************
 * File Name	   : lcd_user.h
 * Version      : 1.0
 * Description  : description
 **********************************************************************************************************************/
/***********************************************************************************************************************
 * History : DD.MM.YYYY Version  Description
 *         : 24.08.2022 1.00     First Release
 **********************************************************************************************************************/

#include <stdio.h>
#include "BAT32G127.h"

/***********************************************************************************************************************
     === LCD panel layout [88:88] (XXXXXX: 1/4bias, 1/8 duty) ===
        ___A___       ___A___
        |     |       |     |
        F     B       F     B
        |     |       |     |
      1 |__G__|     2 |__G__|    .........    x 8  [88 88 88 88]
        |     |       |     |
        E     C       E     C
        |     |       |     |
        ___D___       ___D___

 **********************************************************************************************************************/

/***********************************************************************************************************************
 Macro definitions
 **********************************************************************************************************************/
/*** Modify according to the different LCD panel [Start] ***/

/*** LCD digit number data ***/
#define LCD_DIGIT_LENGTH        8           // Digit length of LCD panel

/* For the 4COM LCD Panel in this application example, 2 SEG lines are required to display 1 number (0 ~ F) */
/* Refer to the above Letters figure for details */
#define LCD_SEGNUM_PER_DIGIT    2           // Segment amount for one character display

#define LCD_D1_SEG_Num1         30           // 1st Segment number connection to 1st digit data
#define LCD_D1_SEG_Num2         29           // 2nd Segment number connection to 1st digit data

#define LCD_D2_SEG_Num1         28           // 1st Segment number connection to 2nd digit data
#define LCD_D2_SEG_Num2         27           // 2nd Segment number connection to 2nd digit data

#define LCD_D3_SEG_Num1         1          // 1st Segment number connection to 3th digit data
#define LCD_D3_SEG_Num2         17          // 2nd Segment number connection to 3th digit data

#define LCD_D4_SEG_Num1         24          // 1st Segment number connection to 4th digit data
#define LCD_D4_SEG_Num2         25          // 2nd Segment number connection to 4th digit data

#define LCD_D5_SEG_Num1         28          // 1st Segment number connection to 5th digit data
#define LCD_D5_SEG_Num2         29          // 2nd Segment number connection to 5th digit data

#define LCD_D6_SEG_Num1         30          // 1st Segment number connection to 6th digit data
#define LCD_D6_SEG_Num2         31          // 2nd Segment number connection to 6th digit data

#define LCD_D7_SEG_Num1         20          // 1st Segment number connection to 7th digit data
#define LCD_D7_SEG_Num2         21          // 2nd Segment number connection to 7th digit data

#define LCD_D8_SEG_Num1         22          // 1st Segment number connection to 8th digit data
#define LCD_D8_SEG_Num2         23          // 2nd Segment number connection to 8th digit data

/* Below is used to define the SEG data (2 data for 1 number) to display the number */
#define LCD_DATA_0_1            0x0B        // 1st SEG Data to display Character "0"
#define LCD_DATA_0_2            0x0E        // 2nd SEG Data to display Character "0"

#define LCD_DATA_1_1            0x00        // 1st SEG Data to display Character "1"
#define LCD_DATA_1_2            0x06        // 2nd SEG Data to display Character "1"

#define LCD_DATA_2_1            0x07        // 1st SEG Data to display Character "2"
#define LCD_DATA_2_2            0x0C        // 2nd SEG Data to display Character "2"

#define LCD_DATA_3_1            0x0A        // 1st SEG Data to display Character "3"
#define LCD_DATA_3_2            0x07        // 2nd SEG Data to display Character "3"

#define LCD_DATA_4_1            0x03        // 1st SEG Data to display Character "4"
#define LCD_DATA_4_2            0x06        // 2nd SEG Data to display Character "4"

#define LCD_DATA_5_1            0x0B        // 1st SEG Data to display Character "5"
#define LCD_DATA_5_2            0x05        // 2nd SEG Data to display Character "5"

#define LCD_DATA_6_1            0x0F        // 1st SEG Data to display Character "6"
#define LCD_DATA_6_2            0x05        // 2nd SEG Data to display Character "6"

#define LCD_DATA_7_1            0x00        // 1st SEG Data to display Character "7"
#define LCD_DATA_7_2            0x07        // 2nd SEG Data to display Character "7"

#define LCD_DATA_8_1            0x0F        // 1st SEG Data to display Character "8"
#define LCD_DATA_8_2            0x07        // 2nd SEG Data to display Character "8"

#define LCD_DATA_9_1            0x0B        // 1st SEG Data to display Character "9"
#define LCD_DATA_9_2            0x07        // 2nd SEG Data to display Character "9"

#define LCD_DATA_A_1            0x07        // 1st SEG Data to display Character "A"
#define LCD_DATA_A_2            0x07        // 2nd SEG Data to display Character "A"

#define LCD_DATA_b_1            0x0F        // 1st SEG Data to display Character "b"
#define LCD_DATA_b_2            0x04        // 2nd SEG Data to display Character "b"

#define LCD_DATA_C_1            0x0D        // 1st SEG Data to display Character "C"
#define LCD_DATA_C_2            0x01        // 2nd SEG Data to display Character "C"

#define LCD_DATA_d_1            0x0E        // 1st SEG Data to display Character "d"
#define LCD_DATA_d_2            0x06        // 2nd SEG Data to display Character "d"

#define LCD_DATA_E_1            0x0F        // 1st SEG Data to display Character "E"
#define LCD_DATA_E_2            0x01        // 2nd SEG Data to display Character "E"

#define LCD_DATA_F_1            0x07        // 1st SEG Data to display Character "F"
#define LCD_DATA_F_2            0x01        // 2nd SEG Data to display Character "F"

#define LCD_DATA_SP             0x00        // 1st/2nd SEG Data to display Character " "


//#define LCD_D1_SEG_Num1         1           // 1st Segment number connection to 1st digit data
//#define LCD_D1_SEG_Num2         0           // 2nd Segment number connection to 1st digit data

//#define LCD_D2_SEG_Num1         3           // 1st Segment number connection to 2nd digit data
//#define LCD_D2_SEG_Num2         2           // 2nd Segment number connection to 2nd digit data

//#define LCD_D3_SEG_Num1         5          // 1st Segment number connection to 3th digit data
//#define LCD_D3_SEG_Num2         4          // 2nd Segment number connection to 3th digit data

//#define LCD_D4_SEG_Num1         7          // 1st Segment number connection to 4th digit data
//#define LCD_D4_SEG_Num2         6          // 2nd Segment number connection to 4th digit data


///* Below is used to define the SEG data (2 data for 1 number) to display the number */
//#define LCD_DATA_0_1            0x07        // 1st SEG Data to display Character "0"
//#define LCD_DATA_0_2            0x0D        // 2nd SEG Data to display Character "0"

//#define LCD_DATA_1_1            0x06        // 1st SEG Data to display Character "1"
//#define LCD_DATA_1_2            0x00        // 2nd SEG Data to display Character "1"

//#define LCD_DATA_2_1            0x03        // 1st SEG Data to display Character "2"
//#define LCD_DATA_2_2            0x0E        // 2nd SEG Data to display Character "2"

//#define LCD_DATA_3_1            0x07        // 1st SEG Data to display Character "3"
//#define LCD_DATA_3_2            0x0A        // 2nd SEG Data to display Character "3"

//#define LCD_DATA_4_1            0x06        // 1st SEG Data to display Character "4"
//#define LCD_DATA_4_2            0x03        // 2nd SEG Data to display Character "4"

//#define LCD_DATA_5_1            0x05        // 1st SEG Data to display Character "5"
//#define LCD_DATA_5_2            0x0B        // 2nd SEG Data to display Character "5"

//#define LCD_DATA_6_1            0x05        // 1st SEG Data to display Character "6"
//#define LCD_DATA_6_2            0x0F        // 2nd SEG Data to display Character "6"

//#define LCD_DATA_7_1            0x07        // 1st SEG Data to display Character "7"
//#define LCD_DATA_7_2            0x00        // 2nd SEG Data to display Character "7"

//#define LCD_DATA_8_1            0x07        // 1st SEG Data to display Character "8"
//#define LCD_DATA_8_2            0x0F        // 2nd SEG Data to display Character "8"

//#define LCD_DATA_9_1            0x07        // 1st SEG Data to display Character "9"
//#define LCD_DATA_9_2            0x0B        // 2nd SEG Data to display Character "9"

//#define LCD_DATA_A_1            0x07        // 1st SEG Data to display Character "A"
//#define LCD_DATA_A_2            0x07        // 2nd SEG Data to display Character "A"

//#define LCD_DATA_b_1            0x04        // 1st SEG Data to display Character "b"
//#define LCD_DATA_b_2            0x0F        // 2nd SEG Data to display Character "b"

//#define LCD_DATA_C_1            0x01        // 1st SEG Data to display Character "C"
//#define LCD_DATA_C_2            0x0D        // 2nd SEG Data to display Character "C"

//#define LCD_DATA_d_1            0x06        // 1st SEG Data to display Character "d"
//#define LCD_DATA_d_2            0x0E        // 2nd SEG Data to display Character "d"

//#define LCD_DATA_E_1            0x01        // 1st SEG Data to display Character "E"
//#define LCD_DATA_E_2            0x0F        // 2nd SEG Data to display Character "E"

//#define LCD_DATA_F_1            0x01        // 1st SEG Data to display Character "F"
//#define LCD_DATA_F_2            0x07        // 2nd SEG Data to display Character "F"

#define LCD_CHAR_TYPE_AMOUNT    16          // Support character in demo codes (0 ~ F)

/*** LCD special dot data ***/
#define LCD_CL1_SEG_NUM         16
#define LCD_DATA_CL1            0x04

/*** Modify according to the different LCD panel [End] ***/

/***********************************************************************************************************************
 Typedef definitions
 **********************************************************************************************************************/
typedef enum
{
    LCD_DISP_DATE   =   1U,                 // Flag to active date-display
    LCD_DISP_TIME   =   2U,                 // Flag to active time-display
    LCD_DISP_NORMAL   =   0xFFU,            // Flag active to number-only-display
} lcd_content_type_t;

/***********************************************************************************************************************
 Global variables
 **********************************************************************************************************************/
extern uint8_t g_rtc_date_buffer[6];
extern uint8_t g_rtc_time_buffer[6];

/***********************************************************************************************************************
 Global functions
 **********************************************************************************************************************/
void LCDUserFunc (uint8_t * disp_buf);
void LCD_NormalCharacter_DataSet (uint8_t disp_buf[], uint8_t *seg_buf);
void LCD_SpecialSymbol_DataSet(uint8_t seg_buf[]);
void LCD_OneDigitCharacter_DataSet(uint8_t char_order, uint8_t char_value, uint8_t seg_buf[]);
void WriteSegReg (void);

