/***********************************************************************************************************************
 * File Name	   : lcd_user.c
 * Version      : 1.0
 * Description  : description
 **********************************************************************************************************************/
/***********************************************************************************************************************
 * History : DD.MM.YYYY Version  Description
 *         : 24.08.2022 1.00     First Release
 **********************************************************************************************************************/
#include "lcd_user.h"

#define TOTAL_SEGMENTS_NUM     42
uint8_t g_seg_data_buffer[ TOTAL_SEGMENTS_NUM ];        // The segment date buffer for LCDC segment registers

/* Segment connection constant table (Digit 1 ~ 8) */
const uint8_t g_lcd_digit_seg_conf[ LCD_DIGIT_LENGTH ][ LCD_SEGNUM_PER_DIGIT ] =
                                   {{LCD_D1_SEG_Num1,LCD_D1_SEG_Num2},{LCD_D2_SEG_Num1,LCD_D2_SEG_Num2},
                                    {LCD_D3_SEG_Num1,LCD_D3_SEG_Num2},{LCD_D4_SEG_Num1,LCD_D4_SEG_Num2},
                                    {LCD_D5_SEG_Num1,LCD_D5_SEG_Num2},{LCD_D6_SEG_Num1,LCD_D6_SEG_Num2},
                                    {LCD_D7_SEG_Num1,LCD_D7_SEG_Num2},{LCD_D8_SEG_Num1,LCD_D8_SEG_Num2}};

/* Support character pattern constant table (Data 0 ~ F) 
	 the data of SEGx depend on the used pannel	*/
const uint8_t g_lcd_data_value_table[LCD_CHAR_TYPE_AMOUNT][ LCD_SEGNUM_PER_DIGIT ] =
                                   {{LCD_DATA_0_1, LCD_DATA_0_2}, {LCD_DATA_1_1, LCD_DATA_1_2},
                                    {LCD_DATA_2_1, LCD_DATA_2_2}, {LCD_DATA_3_1, LCD_DATA_3_2},
                                    {LCD_DATA_4_1, LCD_DATA_4_2}, {LCD_DATA_5_1, LCD_DATA_5_2},
                                    {LCD_DATA_6_1, LCD_DATA_6_2}, {LCD_DATA_7_1, LCD_DATA_7_2},
                                    {LCD_DATA_8_1, LCD_DATA_8_2}, {LCD_DATA_9_1, LCD_DATA_9_2},
                                    {LCD_DATA_A_1, LCD_DATA_A_2}, {LCD_DATA_b_1, LCD_DATA_b_2},
                                    {LCD_DATA_C_1, LCD_DATA_C_2}, {LCD_DATA_d_1, LCD_DATA_d_2},
                                    {LCD_DATA_E_1, LCD_DATA_E_2}, {LCD_DATA_F_1, LCD_DATA_F_2}};

lcd_content_type_t g_lcd_display_type;

void LCD_Buffer_Clear (void)
{
    uint8_t i = 0;
    for (i=0; i <= (TOTAL_SEGMENTS_NUM-1); i++)
    {
        g_seg_data_buffer [i] = 0x00;
    }
} /* End of function LCD_Buffer_Clear() */

/***********************************************************************************************************************
 * Function Name: LCDUserFunc
 * Description  : LCD display data calculate for RTC calendar data display demo
 * Arguments    : LCD display type, LCD display area mode, LCD display buffer
 * Return Value : none
 **********************************************************************************************************************/
void LCDUserFunc (uint8_t * disp_buf)
{
    /* There are some demo code for special symbol display. Modify according to the functional changes. */
    LCD_Buffer_Clear();                                                 // Clear LCD segment date buffer
    LCD_NormalCharacter_DataSet( disp_buf, &g_seg_data_buffer[0] );     // Set the segment date buffer base on the display buffer
    LCD_SpecialSymbol_DataSet(g_seg_data_buffer);
    WriteSegReg();		//write display data to register

} /* End of function LCDUserFunc() */

/***********************************************************************************************************************
 * Function Name: LCD_NormalCharacter_DataSet
 * Description  : Calculate segment date and save to target buffer base display buffer
 * Arguments    : Display data buffer, pointer of segment data buffer
 * Return Value : none
 **********************************************************************************************************************/
void LCD_NormalCharacter_DataSet (uint8_t disp_buf[], uint8_t *seg_buf)
{
    uint8_t i;
    for (i = 0; i < LCD_DIGIT_LENGTH; i++)                                  // LCD_DIGIT_LENGTH: Digit length of LCD panel
    {
        LCD_OneDigitCharacter_DataSet(i, disp_buf[i], seg_buf);             // Set the segment buffer for seven-segment display
    }
} /* End of function LCD_NormalCharacter_DataSet() */

/***********************************************************************************************************************
 * Function Name: LCD_OneDigitCharacter_DataSet
 * Description  : Set target data buffer to support normal character display (0~F)
 * Arguments    : Digit order, display content, target segment data buffer
 * Return Value : none
 **********************************************************************************************************************/
void LCD_OneDigitCharacter_DataSet(uint8_t char_order, uint8_t char_value, uint8_t seg_buf[])
{
    uint8_t i;
    if (char_value <= 0x0F){                    // Display "0~F"
        for (i = 0; i < LCD_SEGNUM_PER_DIGIT; i++)
        {
            // Set the segment buffer according to the value in LCD data constant table
            seg_buf[g_lcd_digit_seg_conf[char_order][i]] = g_lcd_data_value_table[char_value][i];
        }
    }
    else{                                       // Special process
        // buffer = 0xff, display " "
        if (char_value == 0xff){          // Display " "
            for (i = 0; i < LCD_SEGNUM_PER_DIGIT; i++)
            {
                seg_buf[g_lcd_digit_seg_conf[char_order][i]] = LCD_DATA_SP;
            }
        }
    }
} /* End of function LCD_OneDigitCharacter_DataSet() */

/***********************************************************************************************************************
 * Function Name: LCD_SpecialSymbol_DataSet
 * Description  : Set target data buffer to support point(.), underline(_), midline(-) and other symbols.
 * Return Value : none
 **********************************************************************************************************************/
void LCD_SpecialSymbol_DataSet(uint8_t seg_buf[]){
    seg_buf[LCD_D2_SEG_Num2] += 0x08;   // Display DP2
    //seg_buf[LCD_D6_SEG_Num2] += 0x04;   // Display midline2
} /* End of function LCD_SpecialSymbol_DataSet() */


void WriteSegReg (void)
{
    uint8_t i = 0;
    for (i=0; i <= (TOTAL_SEGMENTS_NUM-1); i++)
    {
        *(uint8_t *)((uint32_t)&LCD->SEG0+i) = g_seg_data_buffer [i];
    }
} /* End of function WriteSegReg() */


